@@ -1,4 +1,4 @@
-# $Id: OntologyTerm.pm,v 1.15.4.3 2006/10/02 23:10:12 sendu Exp $
+# $Id: OntologyTerm.pm,v 1.4 2002/10/31 09:45:39 lapp Exp $
 #
 # BioPerl module for Bio::Annotation::OntologyTerm
 #
@@ -8,7 +8,7 @@
 #
 # You may distribute this module under the same terms as perl itself
 
-#
+# 
 # (c) Hilmar Lapp, hlapp at gmx.net, 2002.
 # (c) GNF, Genomics Institute of the Novartis Research Foundation, 2002.
 #
@@ -16,7 +16,7 @@
 # Refer to the Perl Artistic License (see the license accompanying this
 # software package, or see http://www.perl.com/language/misc/Artistic.html)
 # for the terms under which you may use, modify, and redistribute this module.
-#
+# 
 # THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
 # WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
 # MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -47,14 +47,13 @@ Bio::Annotation::OntologyTerm - An ontology term adapted to AnnotationI
    # e.g.
    my $term = $annterm->term(); # term is-a Bio::Ontology::TermI
    print "ontology term ",$term->name()," (ID ",$term->identifier(),
-         "), ontology ",$term->ontology()->name(),"\n";
-   $term = Bio::Ontology::Term->new(-name => 'ABC2',
-                                    -ontology => 'Gene Name');
+         "), category ",$term->category()->name(),"\n";
+   $term = Bio::Ontology::Term->new(-name => 'ABC2', -category => 'Gene Name');
    $annterm->term($term);
 
 =head1 DESCRIPTION
 
-Ontology term annotation object
+Ontology term annotation object 
 
 =head1 FEEDBACK
 
@@ -64,26 +63,27 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to one
 of the Bioperl mailing lists. Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+  bioperl-l@bioperl.org              - General discussion
+  http://bio.perl.org/MailList.html  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via
-the web:
+the bugs and their resolution.  Bug reports can be submitted via email
+or the web:
 
-  http://bugzilla.open-bio.org/
+  bioperl-bugs@bioperl.org
+  http://bugzilla.bioperl.org/
 
 =head1 AUTHOR - Hilmar Lapp
 
+Email bioperl-l@bio.perl.org
 Email hlapp at gmx.net
 
 
 =head1 APPENDIX
 
-The rest of the documentation details each of the object methods.
-Internal methods are usually preceded with a _
+The rest of the documentation details each of the object methods. Internal methods are usually preceded with a _
 
 =cut
 
@@ -92,15 +92,17 @@ Internal methods are usually preceded with a _
 
 
 package Bio::Annotation::OntologyTerm;
+use vars qw(@ISA);
 use strict;
 
 # Object preamble - inherits from Bio::Root::Root
 
+use Bio::AnnotationI;
+use Bio::Ontology::TermI;
 use Bio::Ontology::Term;
-use overload '""' => sub { $_[0]->identifier || ''};
-use overload 'eq' => sub { "$_[0]" eq "$_[1]" };
+use Bio::Root::Root;
 
-use base qw(Bio::Root::Root Bio::AnnotationI Bio::Ontology::TermI);
+@ISA = qw(Bio::Root::Root Bio::AnnotationI Bio::Ontology::TermI);
 
 =head2 new
 
@@ -111,31 +113,33 @@ use base qw(Bio::Root::Root Bio::AnnotationI Bio::Ontology::TermI);
  Args    : -term => $term to initialize the term data field [optional]
            Most named arguments that Bio::Ontology::Term accepts will work
            here too. -label is a synonym for -name, -tagname is a synonym for
-           -ontology.
+           -category.
 
 =cut
 
 sub new{
     my ($class,@args) = @_;
-
+    
     my $self = $class->SUPER::new(@args);
-    my ($term,$name,$label,$identifier,$definition,$ont,$tag) =
+    
+    my ($term,$name,$label,$identifier,$definition,$cat,$tag) =
 	$self->_rearrange([qw(TERM
-                          NAME
-                          LABEL
-                          IDENTIFIER
-                          DEFINITION
-                          ONTOLOGY
-                          TAGNAME)],
-                      @args);
+			      NAME
+			      LABEL
+			      IDENTIFIER
+			      DEFINITION
+			      CATEGORY
+			      TAGNAME)],
+			  @args);
     if($term) {
-        $self->term($term);
+	$self->term($term);
     } else {
-        $self->name($name || $label) if $name || $label;
-        $self->identifier($identifier) if $identifier;
-        $self->definition($definition) if $definition;
+	$self->name($name || $label) if $name || $label;
+	$self->identifier($identifier) if $identifier;
+	$self->definition($definition) if $definition;
     }
-    $self->ontology($ont || $tag) if $ont || $tag;
+    $self->category($cat || $tag) if $cat || $tag;
+
     return $self;
 }
 
@@ -148,11 +152,7 @@ sub new{
 
  Title   : as_text
  Usage   : my $text = $obj->as_text
- Function: Returns a textual representation of the annotation that
-           this object holds. Presently, it is tag name, name of the
-           term, and the is_obsolete attribute concatenated togather
-           with a delimiter (|).
-
+ Function: return the string "Name: $v" where $v is the name of the term
  Returns : string
  Args    : none
 
@@ -162,7 +162,7 @@ sub new{
 sub as_text{
    my ($self) = @_;
 
-   return $self->tagname()."|".$self->name()."|".($self->is_obsolete()||'');
+   return $self->tagname()."|".$self->name()."|".$self->identifier();
 }
 
 =head2 hash_tree
@@ -179,12 +179,12 @@ sub as_text{
 
 sub hash_tree{
    my ($self) = @_;
-
+   
    my $h = {};
    $h->{'name'} = $self->name();
    $h->{'identifier'} = $self->identifier();
    $h->{'definition'} = $self->definition();
-   $h->{'synonyms'} = [$self->get_synonyms()];
+   $h->{'synonyms'} = [$self->each_synonym()];
 }
 
 
@@ -197,8 +197,8 @@ sub hash_tree{
            Setting this is optional. If set, it obviates the need to provide
            a tag to AnnotationCollection when adding this object.
 
-           This is aliased to ontology() here.
- Example :
+           This is aliased to category() here.
+ Example : 
  Returns : value of tagname (a scalar)
  Args    : new value (a scalar, optional)
 
@@ -208,10 +208,10 @@ sub hash_tree{
 sub tagname{
     my $self = shift;
 
-    return $self->ontology(@_) if @_;
-    # if in get mode we need to get the name from the ontology
-    my $ont = $self->ontology();
-    return ref($ont) ? $ont->name() : $ont;
+    return $self->category(@_) if @_;
+    # if in get mode we need to get the name from the category term
+    my $cat = $self->category();
+    return ref($cat) ? $cat->name() : $cat;
 }
 
 =head1 Methods for Bio::Ontology::TermI compliance
@@ -226,7 +226,7 @@ sub tagname{
 
            We implement TermI by composition, and this method sets/gets the
            object we delegate to.
- Example :
+ Example : 
  Returns : value of term (a Bio::Ontology::TermI compliant object)
  Args    : new value (a Bio::Ontology::TermI compliant object, optional)
 
@@ -236,10 +236,10 @@ sub tagname{
 sub term{
     my ($self,$value) = @_;
     if( defined $value) {
-        $self->{'term'} = $value;
+	$self->{'term'} = $value;
     }
     if(! exists($self->{'term'})) {
-        $self->{'term'} = Bio::Ontology::Term->new();
+	$self->{'term'} = Bio::Ontology::Term->new();
     }
     return $self->{'term'};
 }
@@ -293,22 +293,22 @@ sub definition {
     return shift->term()->definition(@_);
 } # definition
 
-=head2 ontology
+=head2 category
 
- Title   : ontology
- Usage   : $term->ontology( $top );
-           or
-           $top = $term->ontology();
+ Title   : category
+ Usage   : $term->category( $top );
+           or 
+           $top = $term->category();
  Function: Set/get for a relationship between this Term and
            another Term (e.g. the top level of the ontology).
- Returns : The ontology of this Term [TermI].
- Args    : The ontology of this Term [TermI or scalar -- which
+ Returns : The category of this Term [TermI].
+ Args    : The category of this Term [TermI or scalar -- which
            becomes the name of the catagory term] (optional).
 
 =cut
 
-sub ontology {
-    return shift->term()->ontology(@_);
+sub category {
+    return shift->term()->category(@_);
 }
 
 =head2 is_obsolete
@@ -331,7 +331,7 @@ sub is_obsolete {
 
  Title   : comment
  Usage   : $term->comment( "Consider the term ..." );
-           or
+           or 
            print $term->comment();
  Function: Set/get for an arbitrary comment about this Term.
  Returns : A comment.
@@ -343,35 +343,35 @@ sub comment {
     return shift->term()->comment(@_);
 } # comment
 
-=head2 get_synonyms
+=head2 each_synonym
 
- Title   : get_synonyms()
- Usage   : @aliases = $term->get_synonyms();
+ Title   : each_synonym()
+ Usage   : @aliases = $term->each_synonym();                 
  Function: Returns a list of aliases of this Term.
  Returns : A list of aliases [array of [scalar]].
  Args    :
 
 =cut
 
-sub get_synonyms {
-    return shift->term()->get_synonyms(@_);
-} # get_synonyms
+sub each_synonym {
+    return shift->term()->each_synonym(@_);
+} # each_synonym
 
-=head2 add_synonym
+=head2 add_synonyms
 
- Title   : add_synonym
- Usage   : $term->add_synonym( @asynonyms );
+ Title   : add_synonyms
+ Usage   : $term->add_synonyms( @asynonyms );
            or
-           $term->add_synonym( $synonym );
+           $term->add_synonyms( $synonym );                  
  Function: Pushes one or more synonyms into the list of synonyms.
- Returns :
+ Returns : 
  Args    : One synonym [scalar] or a list of synonyms [array of [scalar]].
 
 =cut
 
-sub add_synonym {
-    return shift->term()->add_synonym(@_);
-} # add_synonym
+sub add_synonyms {
+    return shift->term()->add_synonyms(@_);
+} # add_synonyms
 
 
 =head2 remove_synonyms
@@ -388,103 +388,5 @@ sub remove_synonyms {
     return shift->term()->remove_synonyms(@_);
 } # remove_synonyms
 
-=head2 get_dblinks
-
- Title   : get_dblinks()
- Usage   : @ds = $term->get_dblinks();
- Function: Returns a list of each dblinks of this GO term.
- Returns : A list of dblinks [array of [scalars]].
- Args    :
-
-=cut
-
-sub get_dblinks {
-    return shift->term->get_dblinks(@_);
-} # get_dblinks
-
-
-=head2 add_dblink
-
- Title   : add_dblink
- Usage   : $term->add_dblink( @dbls );
-           or
-           $term->add_dblink( $dbl );
- Function: Pushes one or more dblinks
-           into the list of dblinks.
- Returns :
- Args    : One  dblink [scalar] or a list of
-            dblinks [array of [scalars]].
-
-=cut
-
-sub add_dblink {
-    return shift->term->add_dblink(@_);
-} # add_dblink
-
-
-=head2 remove_dblinks
-
- Title   : remove_dblinks()
- Usage   : $term->remove_dblinks();
- Function: Deletes (and returns) the definition references of this GO term.
- Returns : A list of definition references [array of [scalars]].
- Args    :
-
-=cut
-
-sub remove_dblinks {
-    return shift->term->remove_dblinks(@_);
-} # remove_dblinks
-
-=head2 get_secondary_ids
-
- Title   : get_secondary_ids
- Usage   : @ids = $term->get_secondary_ids();
- Function: Returns a list of secondary identifiers of this Term.
-
-           Secondary identifiers mostly originate from merging terms,
-           or possibly also from splitting terms.
-
- Returns : A list of secondary identifiers [array of [scalar]]
- Args    :
-
-=cut
-
-sub get_secondary_ids {
-    return shift->term->get_secondary_ids(@_);
-} # get_secondary_ids
-
-
-=head2 add_secondary_id
-
- Title   : add_secondary_id
- Usage   : $term->add_secondary_id( @ids );
-           or
-           $term->add_secondary_id( $id );
- Function: Adds one or more secondary identifiers to this term.
- Returns :
- Args    : One or more secondary identifiers [scalars]
-
-=cut
-
-sub add_secondary_id {
-    return shift->term->add_secondary_id(@_);
-} # add_secondary_id
-
-
-=head2 remove_secondary_ids
-
- Title   : remove_secondary_ids
- Usage   : $term->remove_secondary_ids();
- Function: Deletes (and returns) the secondary identifiers of this Term.
- Returns : The previous list of secondary identifiers [array of [scalars]]
- Args    :
-
-=cut
-
-sub remove_secondary_ids {
-    return shift->term->remove_secondary_ids(@_);
-} # remove_secondary_ids
-
 
 1;
