@@ -1,4 +1,4 @@
-# $Id: MedlineJournalArticle.pm,v 1.10.4.3 2006/10/02 23:10:12 sendu Exp $
+# $Id: MedlineJournalArticle.pm,v 1.3 2002/10/22 07:45:11 lapp Exp $
 #
 # BioPerl module for Bio::Biblio::MedlineJournalArticle
 #
@@ -15,10 +15,10 @@ Bio::Biblio::MedlineJournalArticle - Representation of a MEDLINE journal article
 
     $obj = new Bio::Biblio::MedlineJournalArticle (
                   -title => 'Thermal adaptation analyzed by comparison of protein sequences from mesophilic and extremely thermophilic Methanococcus species.',
-                  -journal => new Bio::Biblio::MedlineJournal (-issn => '0027-8424'),
-                  -volume => 96,
-                  -issue => 7);
-  #--- OR ---
+		  -journal => new Bio::Biblio::MedlineJournal (-issn => '0027-8424'),
+		  -volume => 96,
+		  -issue => 7);
+ --- OR ---
 
     $obj = new Bio::Biblio::MedlineJournalArticle;
     $obj->title ('...');
@@ -28,7 +28,7 @@ Bio::Biblio::MedlineJournalArticle - Representation of a MEDLINE journal article
 
 A storage object for a MEDLINE journal article.
 See its place in the class hierarchy in
-http://www.ebi.ac.uk/~senger/openbqs/images/bibobjects_perl.gif
+http://industry.ebi.ac.uk/openBQS/images/bibobjects_perl.gif
 
 =head2 Attributes
 
@@ -39,15 +39,15 @@ The following attributes are specific to this class
 
 =head1 SEE ALSO
 
-=over 4
+=over
 
 =item *
 
-OpenBQS home page: http://www.ebi.ac.uk/~senger/openbqs/
+OpenBQS home page: http://industry.ebi.ac.uk/openBQS
 
 =item *
 
-Comments to the Perl client: http://www.ebi.ac.uk/~senger/openbqs/Client_perl.html
+Comments to the Perl client: http://industry.ebi.ac.uk/openBQS/Client_perl.html
 
 =back
 
@@ -59,20 +59,21 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+  bioperl-l@bioperl.org              - General discussion
+  http://bioperl.org/MailList.shtml  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via the
-web:
+of the bugs and their resolution. Bug reports can be submitted via
+email or the web:
 
-  http://bugzilla.open-bio.org/
+  bioperl-bugs@bioperl.org
+  http://bugzilla.bioperl.org/
 
 =head1 AUTHORS
 
-Heikki Lehvaslaiho (heikki-at-bioperl-dot-org),
+Heikki Lehvaslaiho (heikki@ebi.ac.uk),
 Martin Senger (senger@ebi.ac.uk)
 
 =head1 COPYRIGHT
@@ -96,8 +97,10 @@ package Bio::Biblio::MedlineJournalArticle;
 use strict;
 use vars qw(@ISA);
 
+use Bio::Biblio::JournalArticle;
+use Bio::Biblio::MedlineArticle;
 
-use base qw(Bio::Biblio::MedlineArticle Bio::Biblio::JournalArticle);
+@ISA = qw(Bio::Biblio::MedlineArticle Bio::Biblio::JournalArticle);
 
 #
 # a closure with a list of allowed attribute names (these names
