@@ -1,4 +1,4 @@
-# $Id: ClusterIO.pm,v 1.18.4.1 2006/10/02 23:10:12 sendu Exp $
+# $Id: ClusterIO.pm,v 1.11 2002/11/02 21:04:18 lapp Exp $
 #
 # BioPerl module for Bio::ClusterIO.pm
 #
@@ -37,7 +37,6 @@ Bio::ClusterIO - Handler for Cluster Formats
       while ( my $sequence = $in->next_seq() ) {
           print $sequence->accession_number() . "\n";
       }
-  }
   # Parsing errors are printed to STDERR.
 
 =head1 DESCRIPTION
@@ -104,15 +103,16 @@ and other Bioperl modules. Send your comments and suggestions preferably
 Your participation is much appreciated.
 
   bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+  http://bioperl.org/MailList.shtml      - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via the
-web:
+ the bugs and their resolution.
+ Bug reports can be submitted via email or the web:
 
-  http://bugzilla.open-bio.org/
+  bioperl-bugs@bioperl.org
+  http://bugzilla.bioperl.org/
 
 =head1 AUTHOR - Andrew Macgregor
 
@@ -131,9 +131,12 @@ methods. Internal methods are usually preceded with a _
 package Bio::ClusterIO;
 
 use strict;
+use vars qw(@ISA);
 
+use Bio::Root::Root;
+use Bio::Root::IO;
 
-use base qw(Bio::Root::Root Bio::Root::IO);
+@ISA = qw(Bio::Root::Root Bio::Root::IO);
 
 
 
@@ -169,7 +172,7 @@ sub new {
 	    $class->_guess_format( $param{-file} || $ARGV[0] );
 	$format = "\L$format";	# normalize capitalization to lower case
 
-	return unless( $class->_load_format_module($format) );
+	return undef unless( $class->_load_format_module($format) );
 	return "Bio::ClusterIO::$format"->new(@args);
     }
 }
