@@ -1,8 +1,8 @@
-# $Id: Collection.pm,v 1.24.4.1 2006/10/02 23:10:13 sendu Exp $
+# $Id: Collection.pm,v 1.11 2002/11/09 09:09:36 heikki Exp $
 #
 # bioperl module for Bio::Coordinate::Collection
 #
-# Cared for by Heikki Lehvaslaiho <heikki-at-bioperl-dot-org>
+# Cared for by Heikki Lehvaslaiho <heikki@ebi.ac.uk>
 #
 # Copyright Heikki Lehvaslaiho
 #
@@ -16,7 +16,7 @@ Bio::Coordinate::Collection - Noncontinuous match between two coordinate sets
 
 =head1 SYNOPSIS
 
-  # create Bio::Coordinate::Pairs or other Bio::Coordinate::MapperIs somehow
+  # create Bio::Coordinate::Pairs somehow
   $pair1; $pair2;
 
   # add them into a Collection
@@ -26,9 +26,9 @@ Bio::Coordinate::Collection - Noncontinuous match between two coordinate sets
 
   # create a position and map it
   $pos = Bio::Location::Simple->new (-start => 5, -end => 9 );
-  $res = $collection->map($pos);
-  $res->match->start == 1;
-  $res->match->end == 5;
+  ok $res = $collection->map($pos);
+  ok $res->match->start, 1;
+  ok $res->match->end, 5;
 
   # if mapping is many to one (*>1) or many-to-many (*>*)
   # you have to give seq_id not get unrelevant entries
@@ -40,19 +40,17 @@ Bio::Coordinate::Collection - Noncontinuous match between two coordinate sets
 Generic, context neutral mapper to provide coordinate transforms
 between two B<disjoint> coordinate systems. It brings into Bioperl the
 functionality from Ewan Birney's Bio::EnsEMBL::Mapper ported into
-current bioperl.
+current bioperl usage.
 
 This class is aimed for representing mapping between whole chromosomes
 and contigs, or between contigs and clones, or between sequencing
 reads and assembly. The submaps are automatically sorted, so they can
 be added in any order.
 
-To map coordinates to the other direction, you have to swap() the
-collection. Keeping track of the direction and ID restrictions
+To map coordinates to other direction, you have to swap() the
+collection. Keeping track of teh direction and when to id restricitons
 are left to the calling code.
 
-
-
 =head1 FEEDBACK
 
 =head2 Mailing Lists
@@ -61,20 +59,26 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to the
 Bioperl mailing lists  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+  bioperl-l@bioperl.org                         - General discussion
+  http://bio.perl.org/MailList.html             - About the mailing lists
 
 =head2 Reporting Bugs
 
 report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via the
-web:
+ the bugs and their resolution.  Bug reports can be submitted via
+ email or the web:
 
-  http://bugzilla.open-bio.org/
+  bioperl-bugs@bio.perl.org
+  http://bugzilla.bioperl.org/
 
 =head1 AUTHOR - Heikki Lehvaslaiho
 
-Email:  heikki-at-bioperl-dot-org
+Email:  heikki@ebi.ac.uk
+Address:
+
+     EMBL Outstation, European Bioinformatics Institute
+     Wellcome Trust Genome Campus, Hinxton
+     Cambs. CB10 1SD, United Kingdom
 
 =head1 CONTRIBUTORS
 
@@ -91,13 +95,16 @@ methods. Internal methods are usually preceded with a _
 # Let the code begin...
 
 package Bio::Coordinate::Collection;
+use vars qw(@ISA );
 use strict;
 
 # Object preamble - inherits from Bio::Root::Root
+use Bio::Root::Root;
+use Bio::Coordinate::MapperI;
 use Bio::Coordinate::Result;
 use Bio::Coordinate::Result::Gap;
 
-use base qw(Bio::Root::Root Bio::Coordinate::MapperI);
+@ISA = qw(Bio::Root::Root Bio::Coordinate::MapperI);
 
 
 sub new {
@@ -127,7 +134,7 @@ sub new {
 
  Title   : add_mapper
  Usage   : $obj->add_mapper($mapper)
- Function: Pushes one Bio::Coordinate::MapperI into the list of mappers.
+ Function: Pushes one Bio::Coodinate::MapperI into the list of mappers.
            Sets _is_sorted() to false.
  Example : 
  Returns : 1 when succeeds, 0 for failure.
@@ -140,12 +147,12 @@ sub add_mapper {
 
   $self->throw("Is not a Bio::Coordinate::MapperI but a [$self]")
       unless defined $value && $value->isa('Bio::Coordinate::MapperI');
-  
+
   # test pair range lengths
-  $self->warn("Coordinates in pair [". $value . ":" .
-	      $value->in->seq_id . "/". $value->out->seq_id .
+  $self->warn("Coodinates in pair [". $value . ":" .
+	      $value->in->seq_id . "/". $value->in->seq_id .
 	      "] are not right.")
-      unless $value->test;
+		  unless $value->test;
 
   $self->_is_sorted(0);
   push(@{$self->{'_mappers'}},$value);
@@ -192,24 +199,6 @@ sub each_mapper{
    return @{$self->{'_mappers'}};
 }
 
-=head2 mapper_count
-
- Title   : mapper_count
- Usage   : my $count = $collection->mapper_count;
- Function: Get the count of the number of mappers stored 
-           in this collection
- Example :
- Returns : integer
- Args    : none
-
-
-=cut
-
-sub mapper_count{
-   my $self = shift;
-   return scalar @{$self->{'_mappers'} || []};
-}
-
 
 =head2 swap
 
@@ -224,13 +213,10 @@ sub mapper_count{
 
 sub swap {
    my ($self) = @_;
-   use Data::Dumper;
 
-   $self->sort unless $self->_is_sorted;
-   map {$_->swap;} @{$self->{'_mappers'}};
-   ($self->{'_in_ids'}, $self->{'_out_ids'}) =
-       ($self->{'_out_ids'}, $self->{'_in_ids'});
-   1;
+   #@{$self->{'mappers'}} = 
+   map {$_->swap} @{$self->{'_mappers'}};
+   $self->sort;
 }
 
 =head2 test
@@ -251,12 +237,10 @@ sub test {
    my $res = 1;
 
    foreach my $mapper ($self->each_mapper) {
-       unless( $mapper->test ) {
-	   $self->warn("Coordinates in pair [". $mapper . ":" .
-		       $mapper->in->seq_id . "/". $mapper->out->seq_id .
-		       "] are not right."); 
-	   $res = 0;
-       }
+       $self->warn("Coodinates in pair [". $mapper . ":" .
+		   $mapper->in->seq_id . "/". $mapper->in->seq_id .
+		   "] are not right.") && ($res = 0)
+	   unless $mapper->test;
    }
    $res;
 }
@@ -265,11 +249,11 @@ sub test {
 =head2 map
 
  Title   : map
- Usage   : $newpos = $obj->map($pos);
- Function: Map the location from the input coordinate system
+ Usage   : $newpos = $obj->map(5);
+ Function: Map the location from the input coordinate system 
            to a new value in the output coordinate system.
  Example :
- Returns : new value in the output coordinate system
+ Returns : new value in the output coordiante system
  Args    : integer
 
 =cut
@@ -286,42 +270,6 @@ sub map {
 
    $self->sort unless $self->_is_sorted;
 
-
-   if ($value->isa("Bio::Location::SplitLocationI")) {
-
-       my $result = new Bio::Coordinate::Result;
-       foreach my $loc ( $value->sub_Location(1) ) {
-
-           my $res = $self->_map($loc);
-           map { $result->add_sub_Location($_) } $res->each_Location;
-
-       }
-       return $result;
-
-   } else {
-       return $self->_map($value);
-   }
-
-
-}
-
-
-=head2 _map
-
- Title   : _map
- Usage   : $newpos = $obj->_map($simpleloc);
- Function: Internal method that does the actual mapping. Called multiple times
-           by map() if the location  to be mapped is a split location
-
- Example :
- Returns : new location in the output coordinate system or undef
- Args    : Bio::Location::Simple
-
-=cut
-
-sub _map {
-   my ($self,$value) = @_;
-
    my $result = Bio::Coordinate::Result->new(-is_remote=>1);
 
 IDMATCH: {
@@ -345,7 +293,17 @@ IDMATCH: {
 	   $result->add_result($subres);
        }
    }
-
+   if ( $self->return_match ) {
+       return undef unless $result->match;
+       if ( $result->each_match > 1 ) {
+	   my @matches = $result->each_match;
+	   return Bio::Location::Simple->new
+	       (-seq_id => $matches[0]->seq_id,
+		-start => $matches[0]->start,
+		-end => $matches[-1]->end,
+		-strand=>$matches[0]->strand );
+       }
+   }
    $result->seq_id($result->match->seq_id) if $result->match;
    unless ($result->each_Location) {
        #build one gap;
