@@ -1,8 +1,8 @@
-# $Id: Pair.pm,v 1.19.4.1 2006/10/02 23:10:14 sendu Exp $
+# $Id: Pair.pm,v 1.9 2002/11/09 09:09:36 heikki Exp $
 #
 # bioperl module for Bio::Coordinate::Pair
 #
-# Cared for by Heikki Lehvaslaiho <heikki-at-bioperl-dot-org>
+# Cared for by Heikki Lehvaslaiho <heikki@ebi.ac.uk>
 #
 # Copyright Heikki Lehvaslaiho
 #
@@ -24,36 +24,28 @@ Bio::Coordinate::Pair - Continuous match between two coordinate sets
   my $match2 = Bio::Location::Simple->new
       (-seq_id => 'peptide', -start => 1, -end => 20, -strand=>1 );
   my $pair = Bio::Coordinate::Pair->new(-in => $match1,
-  					-out => $match2
-                                        );
+  					-out => $match2,
+  				        -negative => 0, # false, default
   # location to match
   $pos = Bio::Location::Simple->new 
       (-start => 25, -end => 25, -strand=> -1 );
 
-  # results are in a Bio::Coordinate::Result
+  # results are in Bio::Coordinate::Result
   # they can be Matches and Gaps; are  Bio::LocationIs
   $res = $pair->map($pos);
   $res->isa('Bio::Coordinate::Result');
-  $res->each_match == 1;
-  $res->each_gap == 0;
-  $res->each_Location == 1;
-  $res->match->start == 5;
-  $res->match->end == 5;
-  $res->match->strand == -1;
-  $res->match->seq_id eq 'peptide';
+  $res->each_match, 1;
+  $res->each_gap, 0;
+  $res->each_location, 1;
+  $res->match->start, 5;
+  $res->match->end, 5;
+  $res->match->strand, -1;
+  $res->match->seq_id, 'peptide';
 
 
 =head1 DESCRIPTION
 
-This class represents a one continuous match between two coordinate
-systems represented by Bio::Location::Simple objects. The relationship
-is directed and reversible. It implements methods to ensure internal
-consistency, and map continuous and split locations from one
-coordinate system to another.
-
-The map() method returns Bio::Coordinate::Results with
-Bio::Coordinate::Result::Gaps. The calling code have to deal (process
-or ignore) them.
+Class
 
 =head1 FEEDBACK
 
@@ -63,20 +55,30 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to the
 Bioperl mailing lists  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+  bioperl-l@bioperl.org                         - General discussion
+  http://bio.perl.org/MailList.html             - About the mailing lists
 
 =head2 Reporting Bugs
 
 report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via the
-web:
+ the bugs and their resolution.  Bug reports can be submitted via
+ email or the web:
 
-  http://bugzilla.open-bio.org/
+  bioperl-bugs@bio.perl.org
+  http://bugzilla.bioperl.org/
 
 =head1 AUTHOR - Heikki Lehvaslaiho
 
-Email:  heikki-at-bioperl-dot-org
+Email:  heikki@ebi.ac.uk
+Address:
+
+     EMBL Outstation, European Bioinformatics Institute
+     Wellcome Trust Genome Campus, Hinxton
+     Cambs. CB10 1SD, United Kingdom
+
+=head1 CONTRIBUTORS
+
+Additional contributors names and emails here
 
 =head1 APPENDIX
 
@@ -89,14 +91,17 @@ methods. Internal methods are usually preceded with a _
 # Let the code begin...
 
 package Bio::Coordinate::Pair;
+use vars qw(@ISA );
 use strict;
 
 # Object preamble - inherits from Bio::Root::Root
+use Bio::Root::Root;
+use Bio::Coordinate::MapperI;
 use Bio::Coordinate::Result;
 use Bio::Coordinate::Result::Match;
 use Bio::Coordinate::Result::Gap;
 
-use base qw(Bio::Root::Root Bio::Coordinate::MapperI);
+@ISA = qw(Bio::Root::Root Bio::Coordinate::MapperI);
 
 
 sub new {
@@ -193,7 +198,7 @@ sub strand {
    $self->warn("Incoming coordinates are not defined")
        unless $self->in;
 
-   return ($self->in->strand || 0) * ($self->out->strand || 0);
+   return $self->in->strand * $self->out->strand;
 }
 
 =head2 test
@@ -213,18 +218,19 @@ sub test {
        unless $self->out;
    $self->warn("Incoming coordinates are not defined")
        unless $self->in;
-   return ($self->in->end - $self->in->start) == ($self->out->end - $self->out->start);
+
+   1 if $self->in->end - $self->in->start == $self->out->end - $self->out->start;
 }
 
 
 =head2 map
 
  Title   : map
- Usage   : $newpos = $obj->map($pos);
- Function: Map the location from the input coordinate system
+ Usage   : $newpos = $obj->map(5);
+ Function: Map the location from the input coordinate system 
            to a new value in the output coordinate system.
  Example :
- Returns : new Bio::LocationI in the output coordinate system or undef
+ Returns : new Bio::LocationI in the output coordiante system
  Args    : Bio::LocationI object
 
 =cut
@@ -241,44 +247,12 @@ sub map {
    $self->throw("Output coordinate system not set")
        unless $self->out;
 
-
-   if ($value->isa("Bio::Location::SplitLocationI")) {
-
-       my $result = new Bio::Coordinate::Result;
-       my $split = new Bio::Location::Split(-seq_id=>$self->out->seq_id);
-       foreach my $loc ( $value->sub_Location(1) ) {
-           my $res = $self->_map($loc);
-           map { $result->add_sub_Location($_) } $res->each_Location;
-       }
-       return $result;
-   } else {
-       return $self->_map($value);
-   }
-}
-
-
-=head2 _map
-
- Title   : _map
- Usage   : $newpos = $obj->_map($simpleloc);
- Function: Internal method that does the actual mapping. Called
-           multiple times by map() if the location to be mapped is a
-           split location
- Example :
- Returns : new location in the output coordinate system or undef
- Args    : Bio::Location::Simple
-
-=cut
-
-sub _map {
-   my ($self,$value) = @_;
-
    my $result = new Bio::Coordinate::Result;
 
    my $offset = $self->in->start - $self->out->start;
-   my $start  = $value->start - $offset;
-   my $end    = $value->end - $offset;
-   
+   my $start = $value->start - $offset;
+   my $end = $value->end - $offset;
+
    my $match = Bio::Location::Simple->new;
    $match->location_type($value->location_type);
    $match->strand($self->strand);
@@ -291,7 +265,7 @@ sub _map {
        $match->seq_id($self->out->seq_id);
        $result->seq_id($self->out->seq_id);
 
-       if ($self->strand >= 0) {
+       if ($self->strand == 1) {
 	   $match->start($start);
 	   $match->end($end);
        } else {
@@ -344,7 +318,7 @@ sub _map {
        # match
        $match->seq_id($self->out->seq_id);
 
-       if ($self->strand >= 0) {
+       if ($self->strand == 1) {
 	   $match->start($self->out->start);
 	   $match->end($end);
        } else {
@@ -365,7 +339,7 @@ sub _map {
 	   $match->strand($match->strand * $value->strand);
 	   $result->strand($match->strand);
        }
-       if ($self->strand >= 0) {
+       if ($self->strand == 1) {
 	   $match->start($start);
 	   $match->end($self->out->end);
        } else {
@@ -426,5 +400,4 @@ sub _map {
    return $result;
 }
 
-
 1;
