@@ -1,8 +1,8 @@
-# $Id: Match.pm,v 1.9.4.1 2006/10/02 23:10:14 sendu Exp $
+# $Id: Match.pm,v 1.2 2002/10/22 07:38:28 lapp Exp $
 #
 # BioPerl module for Bio::Coordinate::Result::Match
 #
-# Cared for by Heikki Lehvaslaiho <heikki-at-bioperl-dot-org>
+# Cared for by Heikki Lehvaslaiho <heikki@ebi.ac.uk>
 #
 # Copywright Heikki Lehvaslaiho
 #
@@ -13,7 +13,7 @@
 
 =head1 NAME
 
-Bio::Coordinate::Result::Match - Another name for Bio::Location::Simple
+Bio::Coordinate::Result::Match - An other name for Bio::Location::Simple
 
 =head1 SYNOPSIS
 
@@ -23,7 +23,7 @@ Bio::Coordinate::Result::Match - Another name for Bio::Location::Simple
 
 =head1 DESCRIPTION
 
-This is a location class for coordinate mapping results.
+This is a location object for coordinate transformation results.
 
 =head1 FEEDBACK
 
@@ -33,20 +33,25 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to one
 of the Bioperl mailing lists.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+  bioperl-l@bioperl.org                         - General discussion
+  http://bio.perl.org/MailList.html             - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via the
-web:
+the bugs and their resolution.  Bug reports can be submitted via email
+or the web:
 
-  http://bugzilla.open-bio.org/
+  bioperl-bugs@bio.perl.org
+  http://bugzilla.bioperl.org/
 
 =head1 AUTHOR - Heikki Lehvaslaiho
 
-Email heikki-at-bioperl-dot-org
+Email heikki@ebi.ac.uk
+
+=head1 CONTRIBUTORS
+
+Additional contributors names and emails here
 
 =head1 APPENDIX
 
@@ -56,10 +61,13 @@ methods. Internal methods are usually preceded with a _
 =cut
 
 package Bio::Coordinate::Result::Match;
+use vars qw(@ISA);
 use strict;
 
+use Bio::Root::Root;
+use Bio::Location::Simple;
 
-use base qw(Bio::Location::Simple Bio::Coordinate::ResultI);
+@ISA = qw(Bio::Location::Simple);
 
 
 1;
