@@ -1,5 +1,5 @@
 #
-# $Id: BDB.pm,v 1.17.4.1 2006/10/02 23:10:16 sendu Exp $
+# $Id: BDB.pm,v 1.6 2002/10/22 07:38:30 lapp Exp $
 #
 # BioPerl module for Bio::DB::Flat::BDB
 #
@@ -15,9 +15,7 @@ Bio::DB::Flat::BDB - Interface for BioHackathon standard BDB-indexed flat file
 
 =head1 SYNOPSIS
 
-  #You should not be using this module directly.
-
-See L<Bio::DB::Flat>.
+You should not be using this module directly.  See Bio::DB::Flat.
 
 =head1 DESCRIPTION
 
@@ -38,8 +36,8 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to one
 of the Bioperl mailing lists.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+  bioperl-l@bioperl.org             - General discussion
+  http://bioperl.org/MailList.shtml - About the mailing lists
 
 =head2 Reporting Bugs
 
@@ -47,7 +45,8 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via
 email or the web:
 
-  http://bugzilla.open-bio.org/
+  bioperl-bugs@bio.perl.org
+  http://bugzilla.bioperl.org/
 
 =head1 AUTHOR - Lincoln Stein
 
@@ -74,12 +73,14 @@ use DB_File;
 use IO::File;
 use Fcntl qw(O_CREAT O_RDWR O_RDONLY);
 use File::Spec;
+use Bio::DB::Flat;
 use Bio::SeqIO;
 use Bio::DB::RandomAccessI;
 use Bio::Root::Root;
 use Bio::Root::IO;
+use vars '@ISA';
 
-use base qw(Bio::DB::Flat);
+@ISA = qw(Bio::DB::Flat);
 
 sub _initialize {
   my $self = shift;
@@ -133,25 +134,12 @@ sub get_Seq_by_id {
 # fetch array of Bio::Seq objects
 sub get_Seq_by_acc {
   my $self = shift;
-  unshift @_,'ACC' if @_==1;
-  my ($ns,$key) = @_;
-  my @primary_ids = $self->expand_ids($ns => $key);
-  $self->throw("more than one sequences correspond to this accession")
-      if @primary_ids > 1 && ! wantarray;
-  my @rc = map {$self->get_Seq_by_id($_)} @primary_ids;
-  return wantarray ? @rc : $rc[0];
-}
-
-# fetch array of Bio::Seq objects
-sub get_Seq_by_version {
-  my $self = shift;
-  unshift @_,'VERSION' if @_==1;
+  return $self->get_Seq_by_id(shift) if @_ == 1;
   my ($ns,$key) = @_;
   my @primary_ids = $self->expand_ids($ns => $key);
   $self->throw("more than one sequences correspond to this accession")
     if @primary_ids > 1 && !wantarray;
-  my @rc = map {$self->get_Seq_by_id($_)} @primary_ids;
-  return wantarray ? @rc : $rc[0];
+  return map {$self->get_Seq_by_id($_)} @primary_ids;
 }
 
 =head2 get_PrimarySeq_stream
@@ -211,9 +199,7 @@ sub build_index {
   my @files = @_;
   my $count = 0;
   for my $file (@files) {
-    $file = File::Spec->rel2abs($file)
-      unless File::Spec->file_name_is_absolute($file);
-    $count += $self->_index_file($file);
+    $count++ if $self->_index_file($file);
   }
   $self->write_config;
   $count;
@@ -228,16 +214,14 @@ sub _index_file {
 
   my $fh     = $self->_fhcache($file) or $self->throw("could not open $file for indexing: $!");
   my $offset = 0;
-  my $count  = 0;
   while (!eof($fh)) {
-    my ($ids,$adjustment)  = $self->parse_one_record($fh) or next;
+    my ($ids,$adjustment)  = $self->parse_one_record($fh);
     $adjustment ||= 0;  # prevent uninit variable warning
     my $pos = tell($fh) + $adjustment;
     $self->_store_index($ids,$file,$offset,$pos-$offset);
     $offset = $pos;
-    $count++;
   }
-  $count;
+  1;
 }
 
 =head2 To Be Implemented in Subclasses
@@ -420,7 +404,7 @@ sub _open_bdb {
 
   my $primary_db = {};
   tie(%$primary_db,'DB_File',$self->_catfile($self->_primary_db_name),$flags,0666,$DB_BTREE)
-    or $self->throw("Could not open primary index file: $! (did you remember to use -write_flag=>1?)");
+    or $self->throw("Could not open primary index file");
   $self->{bdb_primary_db} = $primary_db;
 
   for my $secondary ($self->secondary_namespaces) {
