@@ -45,9 +45,11 @@ package Bio::DB::GFF::Aggregator::transcript;
 use strict;
 use Bio::DB::GFF::Aggregator;
 
-use vars qw(@ISA);
+use vars qw($VERSION @ISA);
 @ISA = qw(Bio::DB::GFF::Aggregator);
 
+$VERSION = '0.10';
+
 =head2 method
 
  Title   : method
