@@ -22,9 +22,15 @@ module.
 package Bio::DB::GFF::Segment;
 
 use strict;
+use Bio::Root::Root;
 use Bio::Annotation::Collection;
+use Bio::RangeI;
+use Bio::Das::SegmentI;
+use Bio::SeqI;
 
-use base qw(Bio::Root::Root Bio::RangeI Bio::SeqI Bio::Das::SegmentI);
+use vars qw($VERSION @ISA);
+@ISA = qw(Bio::Root::Root Bio::RangeI Bio::SeqI Bio::Das::SegmentI);
+$VERSION = '0.31';
 
 use overload 
   '""'     => 'asString',
@@ -97,7 +103,6 @@ to create the segment.
 sub factory { shift->{factory} }
 
 # start, stop, length
-
 =head2 start
 
  Title   : start
@@ -292,85 +297,27 @@ sub subseq {
  Title   : seq
  Usage   : $s->seq
  Function: get the sequence string for this segment
- Returns : a Bio::PrimarySeq
+ Returns : a string
  Args    : none
  Status  : Public
 
-Returns the sequence for this segment as a Bio::PrimarySeq.  (-)
-strand segments are automatically reverse complemented
+Returns the sequence for this segment as a simple string.  (-) strand
+segments are automatically reverse complemented
 
-The method is called dna() return the data as a simple sequence
-string.
+This method is also called dna() and protein() for backward
+compatibility with AceDB.
 
 =cut
 
 sub seq {
-  my $self = shift;
-  my $dna = $self->dna;
-  require Bio::PrimarySeq unless Bio::PrimarySeq->can('new');
-  return Bio::PrimarySeq->new(-seq => $dna,
-			      -id  => $self->display_name);
-}
-
-=head2 dna
-
- Title   : dna
- Usage   : $s->dna
- Function: get the DNA string for this segment
- Returns : a string
- Args    : none
- Status  : Public
-
-Returns the sequence for this segment as a simple string. (-) strand
-segments are automatically reverse complemented
-
-The method is also called protein().
-
-=cut
-
-sub dna {
   my $self = shift;
   my ($ref,$class,$start,$stop,$strand) 
     = @{$self}{qw(sourceseq class start stop strand)};
-  return $self->factory->dna($ref,$start,$stop,$class);
+#  ($start,$stop) = ($stop,$start) if $strand eq '-';
+  $self->factory->dna($ref,$start,$stop,$class);
 }
 
-*protein = \&dna;
-
-
-=head2 primary_seq
-
- Title   : primary_seq
- Usage   : $s->primary_seq
- Function: returns a Bio::PrimarySeqI compatible object
- Returns : a Bio::PrimarySeqI object
- Args    : none
- Status  : Public
-
-This is for compatibility with BioPerl's separation of SeqI
-from PrimarySeqI.  It just returns itself.
-
-=cut
-
-#'
-
-sub primary_seq { shift }
-
-=head2 type
-
- Title   : type
- Usage   : $s->type
- Function: return the string "feature"
- Returns : the string "feature"
- Args    : none
- Status  : Public
-
-This is for future sequence ontology-compatibility and
-represents the default type of a feature on the genome
-
-=cut
-
-sub type { "feature" }
+*protein = *dna = \&seq;
 
 =head2 equals
 
@@ -580,7 +527,6 @@ An alias for refseq() but only allows reading.
 =cut
 
 sub seq_id { shift->refseq }
-*seqname = \&seq_id;
 
 =head2 truncated
 
@@ -702,10 +648,10 @@ sub primary_id {
 }
 
 
-=head2 display_name
+=head2 display_id
 
- Title   : display_name
- Usage   : $id = $obj->display_name or $obj->display_name($newid);
+ Title   : display_id
+ Usage   : $id = $obj->display_id or $obj->display_id($newid);
  Function: Gets or sets the display id, also known as the common name of
            the Seq object.
 
@@ -725,13 +671,10 @@ sub primary_id {
  Returns : A string
  Args    : None or a new id
 
-Note, this used to be called display_id(), and this name is preserved for
-backward compatibility.  The default is to return the seq_id().
 
 =cut
 
-sub display_name { shift->seq_id }
-*display_id = \&display_name;
+sub display_id { shift->seq_id }
 
 =head2 accession_number
 
@@ -793,8 +736,6 @@ sub alphabet{
 
 sub desc { shift->asString }
 
-*description = \&desc;
-
 =head2 species
 
  Title   : species
@@ -840,20 +781,6 @@ sub annotation {
 
 }
 
-=head2 is_circular
-
- Title   : is_circular
- Usage   : if( $obj->is_circular) { /Do Something/ }
- Function: Returns true if the molecule is circular
- Returns : Boolean value
- Args    : none
-
-=cut
-
-sub is_circular{
-    return 0;
-}
-
 
 1;
 __END__
