@@ -1,4 +1,4 @@
-# $Id: WebDBSeqI.pm,v 1.57.2.1 2006/10/02 23:10:15 sendu Exp $
+# $Id: WebDBSeqI.pm,v 1.30 2002/12/09 15:41:12 jason Exp $
 #
 # BioPerl module for Bio::DB::WebDBSeqI
 #
@@ -14,7 +14,7 @@
 =head1 NAME
 
 Bio::DB::WebDBSeqI - Object Interface to generalize Web Databases
-for retrieving sequences
+  for retrieving sequences
 
 =head1 SYNOPSIS
 
@@ -24,15 +24,20 @@ for retrieving sequences
 
 =head1 DESCRIPTION
 
+
+
+
 Provides core set of functionality for connecting to a web based
 database for retriving sequences.
 
 Users wishing to add another Web Based Sequence Dabatase will need to
-extend this class (see L<Bio::DB::SwissProt> or L<Bio::DB::NCBIHelper> for
+extend this class (see Bio::DB::SwissProt or Bio::DB::NCBIHelper for
 examples) and implement the get_request method which returns a
 HTTP::Request for the specified uids (accessions, ids, etc depending
 on what query types the database accepts).
 
+
+
 =head1 FEEDBACK
 
 =head2 Mailing Lists
@@ -43,16 +48,18 @@ your comments and suggestions preferably to one
 of the Bioperl mailing lists. Your participation
 is much appreciated.
 
-  bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+  bioperl-l@bioperl.org              - General discussion
+  http://bioperl.org/MailList.shtml  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to
 help us keep track the bugs and their resolution.
-Bug reports can be submitted via the web.
+Bug reports can be submitted via email or the
+web:
 
-  http://bugzilla.open-bio.org/
+  bioperl-bugs@bio.perl.org
+  http://bugzilla.bioperl.org/
 
 =head1 AUTHOR - Jason Stajich
 
@@ -70,44 +77,42 @@ preceded with a _
 
 package Bio::DB::WebDBSeqI;
 use strict;
-use vars qw($MODVERSION %RETRIEVAL_TYPES $DEFAULT_RETRIEVAL_TYPE
-	    $DEFAULTFORMAT $LAST_INVOCATION_TIME @ATTRIBUTES);
+use vars qw(@ISA $MODVERSION %RETRIEVAL_TYPES $DEFAULT_RETRIEVAL_TYPE
+	    $DEFAULTFORMAT $LAST_INVOCATION_TIME);
 
+use Bio::DB::RandomAccessI;
 use Bio::SeqIO;
 use Bio::Root::IO;
 use LWP::UserAgent;
-use POSIX 'setsid';
 use HTTP::Request::Common;
 use HTTP::Response;
 use File::Spec;
-use IO::Pipe;
 use IO::String;
 use Bio::Root::Root;
 
-use base qw(Bio::DB::RandomAccessI);
+@ISA = qw(Bio::DB::RandomAccessI);
 
 BEGIN {
-	$MODVERSION = '0.8';
-	%RETRIEVAL_TYPES = ('io_string' => 1,
-								 'tempfile'  => 1,
-								 'pipeline'  => 1,
-							 );
-	$DEFAULT_RETRIEVAL_TYPE = 'pipeline';
-	$DEFAULTFORMAT = 'fasta';
-	$LAST_INVOCATION_TIME = 0;
+    $MODVERSION = '0.8';
+    %RETRIEVAL_TYPES = ( 'io_string' => 1,
+			 'tempfile'  => 1,
+			 'pipeline'  => 1,
+		       );
+    $DEFAULT_RETRIEVAL_TYPE = 'pipeline';
+    $DEFAULTFORMAT = 'fasta';
+    $LAST_INVOCATION_TIME = 0;
 }
 
 sub new {
     my ($class, @args) = @_;
     my $self = $class->SUPER::new(@args);
-    my ($baseaddress, $params, $ret_type, $format,$delay,$db) =
-	 $self->_rearrange([qw(BASEADDRESS PARAMS RETRIEVALTYPE FORMAT DELAY DB)],
-							 @args);
+    my ($baseaddress, $params, $ret_type, $format,$delay) =
+	$self->_rearrange([qw(BASEADDRESS PARAMS RETRIEVALTYPE FORMAT DELAY)],
+			  @args);
 
     $ret_type = $DEFAULT_RETRIEVAL_TYPE unless ( $ret_type);
     $baseaddress   && $self->url_base_address($baseaddress);
     $params        && $self->url_params($params);
-    $db            && $self->db($db);
     $ret_type      && $self->retrieval_type($ret_type);
     $delay          = $self->delay_policy unless defined $delay;
     $self->delay($delay);
@@ -118,7 +123,7 @@ sub new {
 					     $format ne '' );
 
     $self->request_format($format);
-    my $ua = new LWP::UserAgent(env_proxy => 1);
+    my $ua = new LWP::UserAgent;
     $ua->agent(ref($self) ."/$MODVERSION");
     $self->ua($ua);  
     $self->{'_authentication'} = [];
@@ -144,11 +149,6 @@ sub get_Seq_by_id {
     $self->_sleep;
     my $seqio = $self->get_Stream_by_id([$seqid]);
     $self->throw("id does not exist") if( !defined $seqio ) ;
-    if ($self->can('complexity') &&  defined $self->complexity && $self->complexity==0) {
-        $self->warn("When complexity is set to 0, use get_Stream_by_id\n".
-                    "Returning Bio::SeqIO object");
-        return $seqio;
-    }
     my @seqs;
     while( my $seq = $seqio->next_seq() ) { push @seqs, $seq; }
     $self->throw("id does not exist") unless @seqs;
@@ -170,15 +170,10 @@ sub get_Seq_by_acc {
    my ($self,$seqid) = @_;
    $self->_sleep;
    my $seqio = $self->get_Stream_by_acc($seqid);
-   $self->throw("acc $seqid does not exist") if( ! defined $seqio );
-    if ($self->can('complexity') &&  defined $self->complexity && $self->complexity==0) {
-        $self->warn("When complexity is set to 0, use get_Stream_by_acc\n".
-                    "Returning Bio::SeqIO object");
-        return $seqio;
-    }
+   $self->throw("acc does not exist") if( ! defined $seqio );
    my @seqs;
    while( my $seq = $seqio->next_seq() ) { push @seqs, $seq; }
-   $self->throw("acc $seqid does not exist") unless @seqs;
+   $self->throw("acc does not exist") unless @seqs;
    if( wantarray ) { return @seqs } else { return shift @seqs }
 }
 
@@ -199,11 +194,6 @@ sub get_Seq_by_gi {
     $self->_sleep;
    my $seqio = $self->get_Stream_by_gi($seqid);
    $self->throw("gi does not exist") if( !defined $seqio );
-    if ($self->can('complexity') &&  defined $self->complexity && $self->complexity==0) {
-        $self->warn("When complexity is set to 0, use get_Stream_by_gi\n".
-                    "Returning Bio::SeqIO object");
-        return $seqio;
-    }
    my @seqs;
    while( my $seq = $seqio->next_seq() ) { push @seqs, $seq; }
    $self->throw("gi does not exist") unless @seqs;
@@ -226,12 +216,7 @@ sub get_Seq_by_version {
     $self->_sleep;
    my $seqio = $self->get_Stream_by_version($seqid);
    $self->throw("accession.version does not exist") if( !defined $seqio );
-    if ($self->can('complexity') &&  defined $self->complexity && $self->complexity==0) {
-        $self->warn("When complexity is set to 0, use get_Stream_by_version\n".
-                    "Returning Bio::SeqIO object");
-        return $seqio;
-    }
-    my @seqs;
+   my @seqs;
    while( my $seq = $seqio->next_seq() ) { push @seqs, $seq; }
    $self->throw("accession.version does not exist") unless @seqs;
    if( wantarray ) { return @seqs } else { return shift @seqs }
@@ -271,9 +256,7 @@ sub get_request {
 
 sub get_Stream_by_id {
     my ($self, $ids) = @_;
-    my ($webfmt,$localfmt) = $self->request_format;
-    return $self->get_seq_stream('-uids' => $ids, '-mode' => 'single',
-				 '-format' => $webfmt);
+    return $self->get_seq_stream('-uids' => $ids, '-mode' => 'single');
 }
 
 *get_Stream_by_batch = sub {
@@ -368,14 +351,6 @@ sub default_format {
     return $DEFAULTFORMAT;
 }
 
-# sorry, but this is hacked in because of BioFetch problems...
-sub db {
-  my $self = shift;
-  my $d    = $self->{_db};
-  $self->{_db} = shift if @_;
-  $d;
-}
-
 =head2 request_format
 
  Title   : request_format
@@ -411,101 +386,96 @@ sub request_format {
 =cut
 
 sub get_seq_stream {
-	my ($self, %qualifiers) = @_;
-	my ($rformat, $ioformat) = $self->request_format();
-	my $seen = 0;
-	foreach my $key ( keys %qualifiers ) {
-		if( $key =~ /format/i ) {
-			$rformat = $qualifiers{$key};
-			$seen = 1;
-		}
-	}
-	$qualifiers{'-format'} = $rformat if( !$seen);
-	($rformat, $ioformat) = $self->request_format($rformat);
-	# These parameters are implemented for Bio::DB::GenBank objects only
-	if($self->isa('Bio::DB::GenBank')) {
-		$self->seq_start() &&  ($qualifiers{'-seq_start'} = $self->seq_start());
-		$self->seq_stop() && ($qualifiers{'-seq_stop'} = $self->seq_stop());
-		$self->strand() && ($qualifiers{'-strand'} = $self->strand());
-		defined $self->complexity() && ($qualifiers{'-complexity'} = $self->complexity());
-	}
-	my $request = $self->get_request(%qualifiers);
-	$request->proxy_authorization_basic($self->authentication)
-	  if ( $self->authentication);
-	$self->debug("request is ". $request->as_string(). "\n");
+  my ($self, %qualifiers) = @_;
+  my ($rformat, $ioformat) = $self->request_format();
+  my $seen = 0;
+  foreach my $key ( keys %qualifiers ) {
+    if( $key =~ /format/i ) {
+      $rformat = $qualifiers{$key};
+      $seen = 1;
+    }
+  }
+  $qualifiers{'-format'} = $rformat if( !$seen);
+  ($rformat, $ioformat) = $self->request_format($rformat);
 
-	# workaround for MSWin systems
-	$self->retrieval_type('io_string') if $self->retrieval_type =~ /pipeline/ && $^O =~ /^MSWin/;
+  my $request = $self->get_request(%qualifiers);
+  $request->proxy_authorization_basic($self->authentication)
+    if ( $self->authentication);
+  $self->debug("request is ". $request->as_string(). "\n");
 
-	if ($self->retrieval_type =~ /pipeline/) {
-		# Try to create a stream using POSIX fork-and-pipe facility.
-		# this is a *big* win when fetching thousands of sequences from
-		# a web database because we can return the first entry while 
-		# transmission is still in progress.
-		# Also, no need to keep sequence in memory or in a temporary file.
-		# If this fails (Windows, MacOS 9), we fall back to non-pipelined access.
+  # workaround for MSWin systems
+  $self->retrieval_type('io_string') if $self->retrieval_type =~ /pipeline/ && $^O =~ /^MSWin/;
 
-		# fork and pipe: _stream_request()=><STREAM>
-		my ($result,$stream) = $self->_open_pipe();
+  if ($self->retrieval_type =~ /pipeline/) {
+    # Try to create a stream using POSIX fork-and-pipe facility.
+    # this is a *big* win when fetching thousands of sequences from
+    # a web database because we can return the first entry while 
+    # transmission is still in progress.
+    # Also, no need to keep sequence in memory or in a temporary file.
+    # If this fails (Windows, MacOS 9), we fall back to non-pipelined access.
 
-		if (defined $result) {
-			$DB::fork_TTY = File::Spec->devnull; # prevents complaints from debugge
-			if (!$result) { # in child process
-			        $self->_stream_request($request,$stream);
-			        POSIX::_exit(0); #prevent END blocks from executing in this forked child
-			}
-			else {
-				return Bio::SeqIO->new('-verbose' => $self->verbose,
-											  '-format'  => $ioformat,
-											  '-fh'      => $stream);
-			}
-		}
-		else {
-			$self->retrieval_type('io_string');
-		}
-	}
+    # fork and pipe: _stream_request()=><STREAM>
+    my $result =  eval { open(STREAM,"-|") };
 
-	if ($self->retrieval_type =~ /temp/i) {
-		my $dir = $self->io->tempdir( CLEANUP => 1);
-		my ( $fh, $tmpfile) = $self->io()->tempfile( DIR => $dir );
-		close $fh;
-		my $resp = $self->_request($request, $tmpfile);		
-		if( ! -e $tmpfile || -z $tmpfile || ! $resp->is_success() ) {
-			$self->throw("WebDBSeqI Error - check query sequences!\n");
-		}
-		$self->postprocess_data('type' => 'file',
-										'location' => $tmpfile);	
-		# this may get reset when requesting batch mode
-		($rformat,$ioformat) = $self->request_format();
-		if( $self->verbose > 0 ) {
-			open(my $ERR, "<", $tmpfile);
-			while(<$ERR>) { $self->debug($_);}
-		}
+    if (defined $result) {
+      $DB::fork_TTY = '/dev/null'; # prevents complaints from debugger
+      if (!$result) {	# in child process
+	$self->_stream_request($request); 
+	kill 9=>$$; # to prevent END{} blocks from executing in forked children
+	exit 0;
+      }
+      else {
+	  return Bio::SeqIO->new('-verbose' => $self->verbose,
+			       '-format'  => $ioformat,
+			       '-fh'      => \*STREAM);
+      }
+    }
+    else {
+      $self->retrieval_type('io_string');
+    }
+  }
 
-		return Bio::SeqIO->new('-verbose' => $self->verbose,
-									  '-format' => $ioformat,
-									  '-file'   => $tmpfile);
-	}
+  if ($self->retrieval_type =~ /temp/i) {
+    my $dir = $self->io->tempdir( CLEANUP => 1);
+    my ( $fh, $tmpfile) = $self->io()->tempfile( DIR => $dir );
+    close $fh;
+    my $resp = $self->_request($request, $tmpfile);		
+    if( ! -e $tmpfile || -z $tmpfile || ! $resp->is_success() ) {
+      $self->throw("WebDBSeqI Error - check query sequences!\n");
+    }
+    $self->postprocess_data('type' => 'file',
+			    'location' => $tmpfile);	
+    # this may get reset when requesting batch mode
+    ($rformat,$ioformat) = $self->request_format();
+    if( $self->verbose > 0 ) {
+      open(ERR, "<$tmpfile");
+      while(<ERR>) { $self->debug($_);}
+    }
 
-	if ($self->retrieval_type =~ /io_string/i ) {
-		my $resp = $self->_request($request);
-		my $content = $resp->content_ref;
-		$self->debug( "content is $$content\n");
-		if (!$resp->is_success() || length($$content) == 0) {
-			$self->throw("WebDBSeqI Error - check query sequences!\n");	
-		}
-		($rformat,$ioformat) = $self->request_format();
-		$self->postprocess_data('type'=> 'string',
-										'location' => $content);
-		$self->debug( "str is $$content\n");
-		return Bio::SeqIO->new('-verbose' => $self->verbose,
-									  '-format' => $ioformat,
-									  '-fh'   => new IO::String($$content));
-	}
+    return Bio::SeqIO->new('-verbose' => $self->verbose,
+			   '-format' => $ioformat,
+			   '-file'   => $tmpfile);
+  }
 
-	# if we got here, we don't know how to handle the retrieval type
-	$self->throw("retrieval type " . $self->retrieval_type . 
-					 " unsupported\n");
+  if ($self->retrieval_type =~ /io_string/i ) {
+    my $resp = $self->_request($request);
+    my $content = $resp->content_ref;
+    $self->debug( "content is $$content\n");
+    if (!$resp->is_success() || length($$content) == 0) {
+      $self->throw("WebDBSeqI Error - check query sequences!\n");	
+    }
+    ($rformat,$ioformat) = $self->request_format();
+    $self->postprocess_data('type'=> 'string',
+			    'location' => $content);
+    $self->debug( "str is $$content\n");
+    return Bio::SeqIO->new('-verbose' => $self->verbose,
+			   '-format' => $ioformat,
+			   '-fh'   => new IO::String($$content));
+  }
+
+  # if we got here, we don't know how to handle the retrieval type
+  $self->throw("retrieval type " . $self->retrieval_type . 
+		 " unsupported\n");
 }
 
 =head2 url_base_address
@@ -543,7 +513,7 @@ sub url_base_address {
 
 sub proxy {
     my ($self,$protocol,$proxy,$username,$password) = @_;
-    return if ( !defined $self->ua || !defined $protocol 
+    return undef if ( !defined $self->ua || !defined $protocol 
 		      || !defined $proxy );
     $self->authentication($username, $password) 	
 	if ($username && $password);
@@ -629,10 +599,10 @@ sub retrieval_type {
 =cut
 
 sub url_params {
-	my ($self, $value) = @_;
-	if( defined $value ) {
-		$self->{'_urlparams'} = $value;
-	}    
+    my ($self, $value) = @_;
+    if( defined $value ) {
+	$self->{'_urlparams'} = $value;
+    }    
 }
 
 =head2 ua
@@ -647,11 +617,11 @@ sub url_params {
 =cut
 
 sub ua {
-	my ($self, $ua) = @_;
-	if( defined $ua && $ua->isa("LWP::UserAgent") ) {
-		$self->{'_ua'} = $ua;
-	}
-	return $self->{'_ua'};
+    my ($self, $ua) = @_;
+    if( defined $ua && $ua->isa("LWP::UserAgent") ) {
+	$self->{'_ua'} = $ua;
+    }
+    return $self->{'_ua'};
 }
 
 =head2 postprocess_data
@@ -668,100 +638,66 @@ sub ua {
 =cut
 
 sub postprocess_data {
-	my ( $self, %args) = @_;
-	return;
+    my ( $self, %args) = @_;
+    return;
 }
 
 # private methods
 sub _request {
-	my ($self, $url,$tmpfile) = @_;
-	my ($resp);
-	if( defined $tmpfile && $tmpfile ne '' ) { 
-		$resp =  $self->ua->request($url, $tmpfile);
-	} else { 
-		$resp =  $self->ua->request($url); 
-	} 
-	
-	if( $resp->is_error  ) {
-		$self->throw("WebDBSeqI Request Error:\n".$resp->as_string);
-	}
-	return $resp;
-}
 
-#mod_perl-safe replacement for the open(BLEH,'-|') call.  if running
-#under mod_perl, detects it and closes the child's STDIN and STDOUT
-#handles
-sub _open_pipe {
-  my ($self) = @_;
+    my ($self, $url,$tmpfile) = @_;
+    my ($resp);
+    if( defined $tmpfile && $tmpfile ne '' ) { 
+	$resp =  $self->ua->request($url, $tmpfile);
+    } else { $resp =  $self->ua->request($url); } 
 
-  if($ENV{MOD_PERL} and ! our $loaded_apache_sp) {
-    eval 'use Apache::SubProcess';
-    $@ and $self->throw("$@\nApache::SubProcess module required for running under mod_perl");
-    $loaded_apache_sp = 1;
-  }
-
-  my $pipe = IO::Pipe->new();
-
-  $SIG{CHLD} = 'IGNORE';
-  defined(my $pid = fork)
-    or $self->throw("Couldn't fork: $!");
-
-  unless($pid) {
-    #CHILD
-    $pipe->writer();
-
-    #if we're running under mod_perl, clean up some things after this fork
-    if ($ENV{MOD_PERL} and my $r = eval{Apache->request} ) {
-      $r->cleanup_for_exec;
-      #don't read or write the mod_perl parent's tied filehandles
-      close STDIN; close STDOUT;
-      setsid() or $self->throw('Could not detach from parent');
+    if( $resp->is_error  ) {
+	$self->throw("WebDBSeqI Request Error:\n".$resp->as_string);
     }
-  } else {
-    #PARENT
-    $pipe->reader();
-  }
-  return ( $pid, $pipe );
+    return $resp;
 }
 
-# send web request to specified filehandle, or stdout, for streaming purposes
+# send web request to stdout for streaming purposes
 sub _stream_request {
   my $self    = shift;
   my $request = shift;
-  my $dest_fh = shift || \*STDOUT;
 
   # fork so as to pipe output of fetch process through to
   # postprocess_data method call.
-  my ($child,$fetch) = $self->_open_pipe();
+  my $child = open (FETCH,"-|");
+  $self->throw("Couldn't fork: $!") unless defined $child;
 
   if ($child) {
-    #PARENT
     local ($/) = "//\n";  # assume genbank/swiss format
     $| = 1;
     my $records = 0;
-    while (my $record = <$fetch>) {
+    while (my $record = <FETCH>) {
       $records++;
       $self->postprocess_data('type'     => 'string',
 			      'location' => \$record);
-      print $dest_fh $record;
+      print STDOUT $record;
     }
     $/ = "\n"; # reset to be safe;
-    close $dest_fh; #must explicitly close here, because the hard
-                    #exits don't cloes them for us
+    close(FETCH);
+    close STDOUT; 
+    close STDERR;
+    kill 9=>$$;  # to prevent END{} blocks from executing in forked children
+    sleep;
   }
   else {
-    #CHILD
     $| = 1;
     my $resp =  $self->ua->request($request,
-				   sub { print $fetch $_[0] }
+				   sub { print shift }
 				   );
     if( $resp->is_error  ) {
       $self->throw("WebDBSeqI Request Error:\n".$resp->as_string);
     }
-    close $fetch; #must explicitly close here, because the hard exists
-                  #don't close them for us
-    POSIX::_exit(0);
+
+    close STDOUT; close STDERR;
+    kill 9=>$$;  # to prevent END{} blocks from executing in forked children
+    sleep;
   }
+  exit 0;
 }
 
 sub io {
