@@ -1,4 +1,4 @@
-# $Id: FTLocationFactory.pm,v 1.9.2.4 2003/09/14 19:15:39 jason Exp $
+# $Id: FTLocationFactory.pm,v 1.9 2002/10/22 07:45:14 lapp Exp $
 #
 # BioPerl module for Bio::Factory::FTLocationFactory
 #
@@ -26,7 +26,7 @@
 
 =head1 NAME
 
-Bio::Factory::FTLocationFactory - A FeatureTable Location Parser
+Bio::Factory::FTLocationFactory - DESCRIPTION of Object
 
 =head1 SYNOPSIS
 
@@ -103,6 +103,14 @@ use Bio::Location::Fuzzy;
 
 =cut
 
+sub new {
+  my($class,@args) = @_;
+
+  my $self = $class->SUPER::new(@args);
+
+  return $self;
+}
+
 =head2 from_string
 
  Title   : from_string
@@ -138,14 +146,13 @@ sub from_string{
 	    # parse the argument recursively, then set the strand to -1
 	    $loc = $self->from_string($oparg, 1);
 	    $loc->strand(-1);
-	} elsif(($op eq "join") || ($op eq "order") || ($op eq "bond")) {
+	} elsif(($op eq "join") || ($op eq "order")) {
 	    # This is a split location. Split into components and parse each
 	    # one recursively, then gather into a SplitLocationI instance.
 	    #
 	    # Note: The following code will /not/ work with nested
 	    # joins (you want to have grammar-based parsing for that).
-	    $loc = Bio::Location::Split->new(-verbose => $self->verbose,
-					     -splittype => $op);
+	    $loc = Bio::Location::Split->new(-splittype => $op);
 	    foreach my $substr (split(/,/, $oparg)) {
 		$loc->add_sub_Location($self->from_string($substr, 1));
 	    }
@@ -205,8 +212,7 @@ sub _parse_location {
 	    $end = $3;
 	    $loctype = $2;
 	    $locclass = "Bio::Location::Fuzzy"
-		unless (abs($end - $start) <= 1) && ($loctype eq "^");
-	    
+		unless (($end-1) == $start) && ($loctype eq "^");
 	} else {
 	    $end = $start;
 	}
@@ -216,10 +222,7 @@ sub _parse_location {
     } 
 
     # instantiate location and initialize
-    $loc = $locclass->new(-verbose => $self->verbose,
-			  -start   => $start, 
-			  -end     => $end, 
-			  -strand  => 1,
+    $loc = $locclass->new(-start => $start, -end  => $end, -strand => 1,
 			  -location_type => $loctype);
     # set remote ID if remote location
     if($seqid) {
