@@ -1,6 +1,6 @@
 package Bio::Graphics::FeatureFile;
 
-# $Id: FeatureFile.pm,v 1.78.4.7 2006/12/02 18:35:32 lstein Exp $
+# $Id: FeatureFile.pm,v 1.20 2002/12/14 00:37:17 lstein Exp $
 # This package parses and renders a simple tab-delimited format for features.
 # It is simpler than GFF, but still has a lot of expressive power.
 # See __END__ for the file format
@@ -39,9 +39,7 @@ Bio::Graphics::FeatureFile -- A set of Bio::Graphics features, stored in a file
  $data->add_type(EST => {fgcolor=>'blue',height=>12});
 
  # add a feature
- my $feature = Bio::Graphics::Feature->new(
-                                             # params
-                                          ); # or some other SeqI
+ my $feature = Bio::Graphics::Feature->new(....); # or some other SeqI
  $data->add_feature($feature=>'EST');
 
 =head1 DESCRIPTION
@@ -53,7 +51,7 @@ FeatureFile object has been initialized, you can interrogate it for
 its consistuent features and their settings, or render the entire file
 onto a Bio::Graphics::Panel.
 
-This module is a precursor of Jason Stajich's
+This moduel is a precursor of Jason Stajich's
 Bio::Annotation::Collection class, and fulfills a similar function of
 storing a collection of sequence features.  However, it also stores
 rendering information about the features, and does not currently
@@ -116,17 +114,16 @@ belong to the same group named yk53c10.
 
 use strict;
 use Bio::Graphics::Feature;
-use Bio::DB::GFF::Util::Rearrange;
-use Carp 'cluck','carp','croak';
-# use Bio::DB::GFF; # not needed - load later
+use Bio::Graphics::Panel;
+use Carp;
 use IO::File;
-use Text::ParseWords 'shellwords';
+use Text::Shellwords;
+use vars '$VERSION';
+$VERSION = '1.04';
 
 # default colors for unconfigured features
 my @COLORS = qw(cyan blue red yellow green wheat turquoise orange);
-
 use constant WIDTH => 600;
-use constant MAX_REMAP => 100;
 
 =head2 METHODS
 
@@ -154,7 +151,7 @@ object.  Arguments are -name=E<gt>value pairs:
 
    -safe           Indicates that the contents of this file is trusted.
                    Any option value that begins with the string "sub {"
-                   or \&subname will be evaluated as a code reference.
+                   will be evaluated as a code reference.
 
 The -file and -text arguments are mutually exclusive, and -file will
 supersede the other if both are present.
@@ -171,11 +168,6 @@ The -smart_features flag is used by the generic genome browser to
 provide features with a way to access the link-generation code.  See
 gbrowse for how this works.
 
-If the file is trusted, and there is an option named "init_code" in
-the [GENERAL] section of the file, it will be evaluated as perl code
-immediately after parsing.  You can use this to declare global
-variables and subroutines for use in option values.
-
 =back
 
 =cut
@@ -193,6 +185,7 @@ sub new {
   my $self = bless {
 		    config   => {},
 		    features => {},
+		    groups   => {},
 		    seenit   => {},
 		    types    => [],
 		    max      => undef,
@@ -203,8 +196,7 @@ sub new {
 		   },$class;
   $self->{coordinate_mapper} = $args{-map_coords} 
     if exists $args{-map_coords} && ref($args{-map_coords}) eq 'CODE';
-
-  $self->smart_features($args{-smart_features})       if exists $args{-smart_features};
+  $self->{smart_features}    = $args{-smart_features} if exists $args{-smart_features};
   $self->{safe}              = $args{-safe}           if exists $args{-safe};
 
   # call with
@@ -233,54 +225,33 @@ sub new {
 
 =over 4
 
-=item ($rendered,$panel) = $features-E<gt>render([$panel, $position_to_insert, $options, $max_bump, $max_label, $selector])
+=item ($rendered,$panel) = $features-E<gt>render([$panel])
 
 Render features in the data set onto the indicated
 Bio::Graphics::Panel.  If no panel is specified, creates one.
 
-All arguments are optional.
-
-$panel is a Bio::Graphics::Panel that has previously been created and
-configured.
-
-$position_to_insert indicates the position at which to start inserting
-new tracks. The last current track on the panel is assumed.
-
-$options is a scalar used to control automatic expansion of the
-tracks. 0=auto, 1=compact, 2=expanded, 3=expand and label,
-4=hyperexpand, 5=hyperexpand and label.
-
-$max_bump and $max_label indicate the maximum number of features
-before bumping and labeling are turned off.
-
-$selector is a code ref that can be used to filter which features to
-render. It receives a feature and should return true to include the
-feature and false to exclude it.
-
 In a scalar context returns the number of tracks rendered.  In a list
-context, returns a three-element list containing the number of
-features rendered, the created panel, and a list of all the track
-objects created.
+context, returns a two-element list containing the number of features
+rendered and the panel.  Use this form if you want the panel created
+for you.
 
 =back
 
 =cut
 
-#"
-
 sub render {
   my $self = shift;
   my $panel = shift;
-  my ($position_to_insert,$options,$max_bump,$max_label,$selector) = @_;
+  my ($position_to_insert,$options,$max_bump,$max_label) = @_;
 
   $panel ||= $self->new_panel;
 
   # count up number of tracks inserted
-  my @tracks;
+  my $tracks = 0;
   my $color;
   my %types = map {$_=>1} $self->configured_types;
 
-  my @configured_types   = grep {exists $self->{features}{$_}} $self->configured_types;
+  my @configured_types   = grep {exists $self->features->{$_}} $self->configured_types;
   my @unconfigured_types = sort grep {!exists $types{$_}}      $self->types;
 
   my @base_config = $self->style('general');
@@ -304,13 +275,7 @@ sub render {
   }
 
   for my $type (@configured_types,@unconfigured_types) {
-    next if defined $selector && !$selector->($self,$type);
-    next unless length $type > 0; # avoid empty ''
-    my $f = $self->features($type);
-    my @features = grep {$self->{visible}{$_} || $_->type eq 'group'} @$f;
-    next unless @features;  # suppress tracks for features that don't appear
-    my $features = \@features;
-
+    my $features = $self->features($type);
     my @auto_bump;
     push @auto_bump,(-bump  => @$features < $max_bump)  if defined $max_bump;
     push @auto_bump,(-label => @$features < $max_label) if defined $max_label;
@@ -318,7 +283,6 @@ sub render {
     my @config = ( -glyph   => 'segments',         # really generic
 		   -bgcolor => $COLORS[$color++ % @COLORS],
 		   -label   => 1,
-		   -description => 1,
 		   -key     => $type,
 		   @auto_bump,
 		   @base_config,         # global
@@ -326,12 +290,13 @@ sub render {
 		   @override,
 		 );
     if (defined($position_to_insert)) {
-      push @tracks,$panel->insert_track($position_to_insert++,$features,@config);
+      $panel->insert_track($position_to_insert++,$features,@config);
     } else {
-      push @tracks,$panel->add_track($features,@config);
+      $panel->add_track($features,@config);
     }
+    $tracks++;
   }
-  return wantarray ? (scalar(@tracks),$panel,\@tracks) : scalar @tracks;
+  return wantarray ? ($tracks,$panel) : $tracks;
 }
 
 sub _stat {
@@ -378,9 +343,8 @@ sub smart_features {
 
 sub parse_argv {
   my $self = shift;
-  $self->init_parse;
 
-  local $/ = "\n";
+  $self->init_parse;
   while (<>) {
     chomp;
     $self->parse_line($_);
@@ -391,14 +355,12 @@ sub parse_argv {
 sub parse_file {
   my $self = shift;
   my $fh   = shift or return;
-
   $self->_stat($fh);
-  $self->init_parse;
 
-  local $/ = "\n";
+  $self->init_parse;
   while (<$fh>) {
     chomp;
-    $self->parse_line($_) || last;
+    $self->parse_line($_);
   }
   $self->finish_parse;
 }
@@ -408,7 +370,7 @@ sub parse_text {
   my $text = shift;
 
   $self->init_parse;
-  foreach (split /\015?\012|\015\012?/,$text) {
+  foreach (split /\r?\n|\r\n?/,$text) {
     $self->parse_line($_);
   }
   $self->finish_parse;
@@ -418,41 +380,25 @@ sub parse_line {
   my $self = shift;
   local $_ = shift;
 
-  s/\015//g;  # get rid of carriage returns left over by MS-DOS/Windows systems
-  s/\s+$//;   # get rid of trailing whitespace
+  s/\r//g;  # get rid of carriage returns left over by MS-DOS/Windows systems
 
-  # capture GFF header
-  if (/^\#\#gff-version\s+(\d+)/) {
-    $self->{gff_version} = $1;
-    require Bio::DB::GFF;
-    return 1;
-  }
+  return if /^\s*[\#]/;
 
-  # remove comments (but rescue hex-code colors)
-  s/\s*\#.+$// unless /\s*\#[0-9A-Fa-f]{6}\b/;
-
-  # skip on blank lines
-  return 1 if /^\s*$/;
-
-  # abort if we see a >FASTA line
-  return 0 if /^>/;
-
-  if (/^\s+(.+)/ && $self->{current_tag}) { # configuration continuation line
-    my $value = $1;
-    my $cc = $self->{current_config} ||= 'general';       # in case no configuration named
-    $self->{config}{$cc}{$self->{current_tag}} .= ' ' . $value;
-    # respect newlines in code subs
-    $self->{config}{$cc}{$self->{current_tag}} .= "\n"
-      if $self->{config}{$cc}{$self->{current_tag}}=~ /^sub\s*\{/;
-    return 1;
+  if (/^\s+(.+)/ && $self->{current_tag}) { # continuation line
+      my $value = $1;
+      my $cc = $self->{current_config} ||= 'general';       # in case no configuration named
+      $self->{config}{$cc}{$self->{current_tag}} .= ' ' . $value;
+      # respect newlines in code subs
+      $self->{config}{$cc}{$self->{current_tag}} .= "\n" if $self->{config}{$cc}{$self->{current_tag}}=~ /^sub\s*{/;
+      return;
   }
 
   if (/^\s*\[([^\]]+)\]/) {  # beginning of a configuration section
-    my $label = $1;
-    my $cc = $label =~ /^(general|default)$/i ? 'general' : $label;  # normalize
-    push @{$self->{types}},$cc unless $cc eq 'general';
-    $self->{current_config} = $cc;
-    return 1;
+     my $label = $1;
+     my $cc = $label =~ /^(general|default)$/i ? 'general' : $label;  # normalize
+     push @{$self->{types}},$cc unless $cc eq 'general';
+     $self->{current_config} = $cc;
+     return;
   }
 
   if (/^([\w: -]+?)\s*=\s*(.*)/) {   # key value pair within a configuration section
@@ -461,66 +407,45 @@ sub parse_line {
     my $value = defined $2 ? $2 : '';
     $self->{config}{$cc}{$tag} = $value;
     $self->{current_tag} = $tag;
-    return 1;
+    return;
   }
 
 
   if (/^$/) { # empty line
     undef $self->{current_tag};
-    return 1;
+    return;
   }
 
-  undef $self->{current_tag};
-
   # parse data lines
-  my @tokens = shellwords($_);
+  my @tokens = eval { shellwords($_||'') };
   unshift @tokens,'' if /^\s+/;
 
   # close any open group
-  if ($self->{group} && $self->{grouptype} && $tokens[0] && length $tokens[0] > 0) {
-    push @{$self->{features}{$self->{grouptype}}},$self->{group};
-    undef $self->{group};
-    undef $self->{grouptype};
-  }
+  undef $self->{grouptype} if length $tokens[0] > 0;
 
   if (@tokens < 3) {      # short line; assume a group identifier
-    my $type               = shift @tokens;
-    my $name               = shift @tokens;
-    $self->{group}         = Bio::Graphics::Feature->new(-name => $name,
-							 -type => 'group');
-    $self->{grouptype}     = $type;
-    return 1;
+    $self->{grouptype}     = shift @tokens;
+    $self->{groupname}     = shift @tokens;
+    return;
   }
 
-  my($ref,$type,$name,$strand,$bounds,$description,$url,$score,%attributes);
+  my($ref,$type,$name,$strand,$bounds,$description,$url);
 
-  my @parts;
-
-  # conventional GFF file, with check for numeric start/end
-  if (@tokens >= 8 && $tokens[3]=~ /^-?\d+$/ && $tokens[4]=~ /^-?\d+$/) {
-    require Bio::DB::GFF unless Bio::DB::GFF->can('split_group');
-    my ($r,$source,$method,$start,$stop,$scor,$s,$phase,@rest) = @tokens;
-    # sanity checks
+  if (@tokens >= 8) { # conventional GFF file
+    my ($r,$source,$method,$start,$stop,$score,$s,$phase,@rest) = @tokens;
     my $group = join ' ',@rest;
-    $type   = defined $source && $source ne '.' ? join(':',$method,$source) : $method;
-    #$bounds = join '..',$start,$stop;
-    @parts   = ([$start,$stop]);
+    $type   = join(':',$method,$source);
+    $bounds = join '..',$start,$stop;
     $strand = $s;
     if ($group) {
       my ($notes,@notes);
-      (undef,$name,undef,undef,$notes) = $self->split_group($group);
+      (undef,$self->{groupname},undef,undef,$notes) = split_group($group);
       foreach (@$notes) {
-	my ($key,$value) = @$_;
-	if ($value =~ m!^(http|ftp)://!) { 
-	  $url = $_ 
-	} else {
-	  push @notes,"$key=$value";
-	}
+	if (m!^(http|ftp)://!) { $url = $_ } else { push @notes,$_ }
       }
-      $description = join '; ',map {_escape($_)} @notes if @notes;
-      $score       = $scor if defined $scor && $scor ne '.';
+      $description = join '; ',@notes if @notes;
     }
-    $name ||= $self->{group}->display_id if $self->{group};
+    $name ||= $self->{groupname};
     $ref = $r;
   }
 
@@ -543,120 +468,43 @@ sub parse_line {
   }
   $self->{refs}{$ref}++ if defined $ref;
 
-  @parts = map { [/(-?\d+)(?:-|\.\.)(-?\d+)/]} split /(?:,| )\s*/,$bounds
-    if $bounds && !@parts;
+  my @parts = map { [/(-?\d+)(?:-|\.\.)(-?\d+)/]} split /(?:,| )\s*/,$bounds;
 
   foreach (@parts) { # max and min calculation, sigh...
-    $self->{min} = $_->[0] if defined $_->[0] && defined $self->{min} ? ($_->[0] < $self->{min}) : 1;
-    $self->{max} = $_->[1] if defined $_->[1] && defined $self->{max} ? ($_->[1] > $self->{max}) : 1;
+    $self->{min} = $_->[0] if !defined $self->{min} || $_->[0] < $self->{min};
+    $self->{max} = $_->[1] if !defined $self->{max} || $_->[1] > $self->{max};
   }
 
-  my $visible = 1;
-
   if ($self->{coordinate_mapper} && $ref) {
-    my @remapped = $self->{coordinate_mapper}->($ref,@parts);
-    ($ref,@parts) = @remapped if @remapped;
-    $visible   = @remapped;
-    return 1 if !$visible && $self->{feature_count} > MAX_REMAP;
+    ($ref,@parts) = $self->{coordinate_mapper}->($ref,@parts);
+    return unless $ref;
   }
 
   $type = '' unless defined $type;
   $name = '' unless defined $name;
 
-  # if strand is not explicitly given in file, we infer it
-  # from the order of start and end coordinates
-  # (this is to deal with confusing documentation, actually)
-  unless (defined $strand) {
-    foreach (@parts) {
-      if (defined $_ && ref($_) eq 'ARRAY' && defined $_->[0] && defined $_->[1]) {
-        $strand           ||= $_->[0] <= $_->[1] ? '+' : '-';
-        ($_->[0],$_->[1])   = ($_->[1],$_->[0]) if $_->[0] > $_->[1];
-      }
-    }
-  }
-
-  # attribute handling
-  if (defined $description && $description =~ /\w+=\S+/) { # attribute line
-    my @attributes = split /;\s*/,$description;
-    foreach (@attributes) {
-      my ($name,$value) = split /=/,$_,2;
-      Bio::Root::Root->throw(qq("$_" is not a valid attribute=value pair)) unless defined $value;
-      _unescape($name);
-      my @values = split /,/,$value;
-      _unescape(@values);
-      if ($name =~ /^(note|description)/) {
-	$description = "@values";
-      } elsif ($name eq 'url') {
-	$url = $value;
-      } elsif ($name eq 'score') {
-	$score = $value;
-      } else {
-	push @{$attributes{$name}},@values;
-      }
-    }
-  }
-
   # either create a new feature or add a segment to it
   if (my $feature = $self->{seenit}{$type,$name}) {
-
-    # create a new segment to hold the parts
-    if (!$feature->segments) {
-      my $new_segment  = bless {%$feature},ref $feature;
-      $feature->add_segment($new_segment);
-    }
-    # add the segments
-    $feature->add_segment(map {
-      _make_feature($name,$type,$strand,$description,$ref,\%attributes,$url,$score,[$_])
-    }  @parts);
-    $self->{visible}{$feature}++  if $visible;
-  }
-
-  else {
-    $feature = $self->{seenit}{$type,$name} = _make_feature($name,$type,$strand,
-							    $description,$ref,
-							    \%attributes,$url,$score,\@parts);
+    $feature->add_segment(@parts);
+  } else {
+    $feature = $self->{seenit}{$type,$name} = 
+      Bio::Graphics::Feature->new(-name     => $name,
+				  -type     => $type,
+				  $strand ? (-strand   => make_strand($strand)) : (),
+				  -segments => \@parts,
+				  -desc     => $description,
+				  -ref      => $ref,
+				  defined($url) ? (-url      => $url) : (),
+				 );
     $feature->configurator($self) if $self->smart_features;
-    if ($self->{group}) {
-      $self->{group}->add_segment($feature);
+    if ($self->{grouptype}) {
+      push @{$self->{groups}{$self->{grouptype}}{$self->{groupname}}},$feature;
     } else {
       push @{$self->{features}{$type}},$feature;  # for speed; should use add_feature() instead
-      $self->{visible}{$feature}++  if $visible;
-      $self->{feature_count}++;
     }
   }
-
-  return 1;
 }
 
-sub _unescape {
-  foreach (@_) {
-    tr/+/ /;       # pluses become spaces
-    s/%([0-9a-fA-F]{2})/chr hex($1)/g;
-  }
-  @_;
-}
-
-sub _escape {
-  my $toencode = shift;
-  $toencode =~ s/([^a-zA-Z0-9_.=-])/uc sprintf("%%%02x",ord($1))/eg;
-  $toencode;
-}
-
-sub _make_feature {
-  my ($name,$type,$strand,$description,$ref,$attributes,$url,$score,$parts) = @_;
-  my @coordinates = @$parts > 1 ? (-segments => $parts) : (-start=>$parts->[0][0],-end=>$parts->[0][1]);
-  Bio::Graphics::Feature->new(-name       => $name,
-			      -type       => $type,
-			      -subtype    => "${type}_part",
-			      $strand ? (-strand   => make_strand($strand)) : (),
-			      -desc       => $description,
-			      -ref        => $ref,
-			      -attributes => $attributes,
-			      defined $url   ? (-url  => $url) : (),
-			      defined $score ? (-score=>$score) : (),
-			      @coordinates,
-			     );
-}
 
 =over 4
 
@@ -675,10 +523,7 @@ feature's primary_tag() method will be invoked to get the type.
 sub add_feature {
   my $self = shift;
   my ($feature,$type) = @_;
-  $feature->configurator($self) if $self->smart_features;
   $type = $feature->primary_tag unless defined $type;
-  $self->{visible}{$feature}++;
-  $self->{feature_count}++;
   push @{$self->{features}{$type}},$feature;
 }
 
@@ -745,12 +590,12 @@ sub set {
 }
 
 # break circular references
-sub finished {
+sub destroy {
   my $self = shift;
   delete $self->{features};
 }
 
-sub DESTROY { shift->finished(@_) }
+sub DESTROY { shift->destroy(@_) }
 
 =over 4
 
@@ -777,9 +622,6 @@ Call with no elements to retrieve all stanza names:
 
 sub setting {
   my $self = shift;
-  if (@_ > 2) {
-    $self->{config}->{$_[0]}{$_[1]} = $_[2];
-  }
   if ($self->safe) {
      $self->code_setting(@_);
   } else {
@@ -790,15 +632,12 @@ sub setting {
 # return configuration information
 # arguments are ($type) => returns tags for type
 #               ($type=>$tag) => returns values of tag on type
-#               ($type=>$tag,$value) => sets value of tag
 sub _setting {
   my $self = shift;
   my $config = $self->{config} or return;
   return keys %{$config} unless @_;
-  return keys %{$config->{$_[0]}}        if @_ == 1;
-  return $config->{$_[0]}{$_[1]}         if @_ == 2 && exists $config->{$_[0]};
-  return $config->{$_[0]}{$_[1]} = $_[2] if @_ > 2;
-  return;
+  return keys %{$config->{$_[0]}} if @_ == 1;
+  return $config->{$_[0]}{$_[1]}  if @_ > 1;
 }
 
 
@@ -823,30 +662,11 @@ sub code_setting {
   my $setting = $self->_setting($section=>$option);
   return unless defined $setting;
   return $setting if ref($setting) eq 'CODE';
-  if ($setting =~ /^\\&(\w+)/) {  # coderef in string form
-    my $subroutine_name = $1;
-    my $package         = $self->base2package;
-    my $codestring      = "\\&${package}\:\:${subroutine_name}";
-    my $coderef         = eval $codestring;
-    $self->_callback_complain($section,$option) if $@;
-    $self->set($section,$option,$coderef);
-    return $coderef;
-  }
-  elsif ($setting =~ /^sub\s*(\(\$\$\))*\s*\{/) {
-    my $package         = $self->base2package;
-    my $coderef         = eval "package $package; $setting";
-    $self->_callback_complain($section,$option) if $@;
-    $self->set($section,$option,$coderef);
-    return $coderef;
-  } else {
-    return $setting;
-  }
-}
-
-sub _callback_complain {
-  my $self    = shift;
-  my ($section,$option) = @_;
-  carp "An error occurred while evaluating the callback at section='$section', option='$option':\n   => $@";
+  return $setting unless $setting =~ /^sub\s*\{/;
+  my $coderef = eval $setting;
+  warn $@ if $@;
+  $self->set($section,$option,$coderef);
+  return $coderef;
 }
 
 =over 4
@@ -890,11 +710,7 @@ sub style {
   my $type = shift;
 
   my $config  = $self->{config}  or return;
-  my $hashref = $config->{$type};
-  unless ($hashref) {
-    $type =~ s/:.+$//;
-    $hashref = $config->{$type} or return;
-  }
+  my $hashref = $config->{$type} or return;
 
   return map {("-$_" => $hashref->{$_})} keys %$hashref;
 }
@@ -958,56 +774,6 @@ sub types {
   return keys %{$features};
 }
 
-=over 4
-
-=item $features = $features-E<gt>features($type)
-
-Return a list of all the feature types of type "$type".  If the
-featurefile object was created by parsing a file or text scalar, then
-the features will be of type Bio::Graphics::Feature (which follow the
-Bio::FeatureI interface).  Otherwise the list will contain objects of
-whatever type you added with calls to add_feature().
-
-Two APIs:
-
-  1) original API:
-
-      # Reference to an array of all features of type "$type"
-      $features = $features-E<gt>features($type)
-
-      # Reference to an array of all features of all types
-      $features = $features-E<gt>features()
-
-      # A list when called in a list context
-      @features = $features-E<gt>features()
-
-   2) Bio::Das::SegmentI API:
-
-       @features = $features-E<gt>features(-type=>['list','of','types']);
-
-       # variants
-       $features = $features-E<gt>features(-type=>['list','of','types']);
-       $features = $features-E<gt>features(-type=>'a type');
-       $iterator = $features-E<gt>features(-type=>'a type',-iterator=>1);
-
-=back
-
-=cut
-
-# return features
-sub features {
-  my $self = shift;
-  my ($types,$iterator,@rest) = defined($_[0] && $_[0]=~/^-/)
-    ? rearrange([['TYPE','TYPES']],@_) : (\@_);
-  $types = [$types] if $types && !ref($types);
-  my @types = ($types && @$types) ? @$types : $self->types;
-  my @features = map {@{$self->{features}{$_}}} @types;
-  if ($iterator) {
-    require Bio::Graphics::FeatureFile::Iterator;
-    return Bio::Graphics::FeatureFile::Iterator->new(\@features);
-  }
-  return wantarray ? @features : \@features;
-}
 
 =over 4
 
@@ -1023,6 +789,15 @@ whatever type you added with calls to add_feature().
 
 =cut
 
+# return features
+sub features {
+  my $self = shift;
+  return $self->{features}{shift()} if @_;
+  return $self->{features};
+}
+
+
+
 sub make_strand {
   local $^W = 0;
   return +1 if $_[0] =~ /^\+/ || $_[0] > 0;
@@ -1030,154 +805,6 @@ sub make_strand {
   return 0;
 }
 
-=head2 get_seq_stream
-
- Title   : get_seq_stream
- Usage   : $stream = $s->get_seq_stream(@args)
- Function: get a stream of features that overlap this segment
- Returns : a Bio::SeqIO::Stream-compliant stream
- Args    : see below
- Status  : Public
-
-This is the same as feature_stream(), and is provided for Bioperl
-compatibility.  Use like this:
-
- $stream = $s->get_seq_stream('exon');
- while (my $exon = $stream->next_seq) {
-    print $exon->start,"\n";
- }
-
-=cut
-
-sub get_seq_stream {
-  my $self = shift;
-  local $^W = 0;
-  my @args = $_[0] =~ /^-/ ? (@_,-iterator=>1) : (-types=>\@_,-iterator=>1);
-  $self->features(@args);
-}
-
-=head2 get_feature_by_name
-
- Usage   : $db->get_feature_by_name(-name => $name)
- Function: fetch features by their name
- Returns : a list of Bio::DB::GFF::Feature objects
- Args    : the name of the desired feature
- Status  : public
-
-This method can be used to fetch a named feature from the file.
-
-The full syntax is as follows.  Features can be filtered by
-their reference, start and end positions
-
-  @f = $db->get_feature_by_name(-name  => $name,
-                                -ref   => $sequence_name,
-                                -start => $start,
-                                -end   => $end);
-
-This method may return zero, one, or several Bio::Graphics::Feature
-objects.
-
-=cut
-
-sub get_feature_by_name {
-   my $self = shift;
-   my ($name,$ref,$start,$end) = rearrange(['NAME','REF','START','END'],@_);
-   my $match = <<'END';
-sub {
-        my $f = shift;
-END
-   if (defined $name) {
-      if ($name =~ /[\?\*]/) {  # regexp
-        $name =  quotemeta($name);
-        $name =~ s/\\\?/.?/g;
-        $name =~ s/\\\*/.*/g;
-        $match .= "     return unless \$f->display_name =~ /$name/i;\n";
-      } else {
-        $match .= "     return unless \$f->display_name eq '$name';\n";
-      }
-   }
-
-   if (defined $ref) {
-      $match .= "     return unless \$f->ref eq '$ref';\n";
-   }
-   if (defined $start && $start =~ /^-?\d+$/) {
-      $match .= "     return unless \$f->stop >= $start;\n";
-   }
-   if (defined $end && $end =~ /^-?\d+$/) {
-      $match .= "     return unless \$f->start <= $end;\n";
-   }
-   $match .= "     return 1;\n}";
-
-   my $match_sub = eval $match;
-   unless ($match_sub) {
-     warn $@;
-     return;
-   }
-
-   return grep {$match_sub->($_)} $self->features;
-}
-
-=head2 search_notes
-
- Title   : search_notes
- Usage   : @search_results = $db->search_notes("full text search string",$limit)
- Function: Search the notes for a text string
- Returns : array of results
- Args    : full text search string, and an optional row limit
- Status  : public
-
-Each row of the returned array is a arrayref containing the following fields:
-
-  column 1     Display name of the feature
-  column 2     The text of the note
-  column 3     A relevance score.
-
-=cut
-
-sub search_notes {
-  my $self = shift;
-  my ($search_string,$limit) = @_;
-
-  $search_string =~ tr/*?//d;
-
-  my @results;
-  my $search = join '|',map {quotemeta($_)} $search_string =~ /(\S+)/g;
-
-  for my $feature ($self->features) {
-    next unless $feature->{attributes};
-    my @attributes = $feature->all_tags;
-    my @values     = map {$feature->each_tag_value} @attributes;
-    push @values,$feature->notes        if $feature->notes;
-    push @values,$feature->display_name if $feature->display_name;
-    next unless @values;
-    my $value      = "@values";
-    my $matches    = 0;
-    my $note;
-    my @hits = $value =~ /($search)/ig;
-    $note ||= $value if @hits;
-    $matches += @hits;
-    next unless $matches;
-
-    my $relevance = 10 * $matches;
-    push @results,[$feature,$note,$relevance];
-    last if @results >= $limit;
-  }
-
-  @results;
-}
-
-
-=head2 get_feature_stream(), top_SeqFeatures(), all_SeqFeatures()
-
-Provided for compatibility with older BioPerl and/or Bio::DB::GFF
-APIs.
-
-=cut
-
-*get_feature_stream = \&get_seq_stream;
-*top_SeqFeatures    = *all_SeqFeatures = \&features;
-
-
 =over 4
 
 =item @refs = $features-E<gt>refs
@@ -1222,24 +849,33 @@ sub init_parse {
   my $s = shift;
 
   $s->{seenit} = {}; 
-  $s->{max}         = $s->{min} = undef;
-  $s->{types}       = [];
-  $s->{features}    = {};
-  $s->{config}      = {};
-  $s->{gff_version} = 0;
-  $s->{feature_count}=0; 
+  $s->{max}      = $s->{min} = undef;
+  $s->{types}    = [];
+  $s->{groups}   = {};
+  $s->{features} = {};
+  $s->{config}   = {}
 }
 
 sub finish_parse {
   my $s = shift;
+  $s->consolidate_groups;
   $s->evaluate_coderefs if $s->safe;
   $s->{seenit} = {};
-  delete $s->{gff_version};
+  $s->{groups} = {};
+}
+
+sub consolidate_groups {
+  my $self = shift;
+  my $groups = $self->{groups} or return;
+
+  for my $type (keys %$groups) {
+    my @groups = values %{$groups->{$type}};
+    push @{$self->{features}{$type}},@groups;
+  }
 }
 
 sub evaluate_coderefs {
   my $self = shift;
-  $self->initialize_code();
   for my $s ($self->_setting) {
     for my $o ($self->_setting($s)) {
       $self->code_setting($s,$o);
@@ -1247,34 +883,55 @@ sub evaluate_coderefs {
   }
 }
 
-sub initialize_code {
-  my $self       = shift;
-  my $package = $self->base2package;
-  my $init_code = $self->_setting(general => 'init_code') or return;
-  my $code = "package $package; $init_code; 1;";
-  eval $code;
-  $self->_callback_complain(general=>'init_code') if $@;
-}
-
-sub base2package {
-  my $self = shift;
-  (my $package = overload::StrVal($self)) =~ s/[^a-z0-9A-Z_]/_/g;
-  $package     =~ s/^[^a-zA-Z_]/_/g;
-  $package;
-}
-
 sub split_group {
-  my $self = shift;
-  my $gff = $self->{gff} ||= Bio::DB::GFF->new(-adaptor=>'memory');
-  return $gff->split_group(shift, $self->{gff_version} > 2);
+  my $group = shift;
+
+  $group =~ s/\\;/$;/g;  # protect embedded semicolons in the group
+  $group =~ s/( \"[^\"]*);([^\"]*\")/$1$;$2/g;
+  my @groups = split(/\s*;\s*/,$group);
+  foreach (@groups) { s/$;/;/g }
+
+  my ($gclass,$gname,$tstart,$tstop,@notes);
+
+  foreach (@groups) {
+
+    my ($tag,$value) = /^(\S+)\s*(.*)/;
+    $value =~ s/\\t/\t/g;
+    $value =~ s/\\r/\r/g;
+    $value =~ s/^"//;
+    $value =~ s/"$//;
+
+    # if the tag is "Note", then we add this to the
+    # notes array
+   if ($tag eq 'Note') {  # just a note, not a group!
+     push @notes,$value;
+   }
+
+    # if the tag eq 'Target' then the class name is embedded in the ID
+    # (the GFF format is obviously screwed up here)
+    elsif ($tag eq 'Target' && $value =~ /([^:\"]+):([^\"]+)/) {
+      ($gclass,$gname) = ($1,$2);
+      ($tstart,$tstop) = /(\d+) (\d+)/;
+    }
+
+    elsif (!$value) {
+      push @notes,$tag;  # e.g. "Confirmed_by_EST"
+    }
+
+    # otherwise, the tag and value correspond to the
+    # group class and name
+    else {
+      ($gclass,$gname) = ($tag,$value);
+    }
+  }
+
+  return ($gclass,$gname,$tstart,$tstop,\@notes);
 }
 
 # create a panel if needed
 sub new_panel {
   my $self = shift;
 
-  require Bio::Graphics::Panel;
-
   # general configuration of the image here
   my $width         = $self->setting(general => 'pixels')
                       || $self->setting(general => 'width')
@@ -1295,8 +952,7 @@ sub new_panel {
   my $new_segment = Bio::Graphics::Feature->new(-start=>$start,-stop=>$stop);
   my $panel = Bio::Graphics::Panel->new(-segment   => $new_segment,
 					-width     => $width,
-					-key_style => 'between',
-					$self->style('general'));
+					-key_style => 'between');
   $panel;
 }
 
@@ -1343,17 +999,15 @@ interface) or its primary_tag() method otherwise.
 sub feature2label {
   my $self = shift;
   my $feature = shift;
-  my $type  = $feature->primary_tag or return;
+  my $type  = eval {$feature->type} || $feature->primary_tag or return;
   (my $basetype = $type) =~ s/:.+$//;
-  my @labels = $self->type2label($type);
-  @labels = $self->type2label($basetype) unless @labels;
-  @labels = ($type) unless @labels;;
-  wantarray ? @labels : $labels[0];
+  my $label = $self->type2label($type) || $self->type2label($basetype) || $type;
+  $label;
 }
 
 =over 4
 
-=item $link = $features-E<gt>link_pattern($linkrule,$feature,$panel)
+=item $link = $features-E<gt>make_link($feature)
 
 Given a feature, tries to generate a URL to link out from it.  This
 uses the 'link' option, if one is present.  This method is a
@@ -1363,94 +1017,41 @@ convenience for the generic genome browser.
 
 =cut
 
-sub link_pattern {
-  my $self     = shift;
-  my ($linkrule,$feature,$panel) = @_;
-
-  $panel ||= 'Bio::Graphics::Panel';
-
-  if (ref($linkrule) && ref($linkrule) eq 'CODE') {
-    my $val = eval {$linkrule->($feature,$panel)};
-    $self->_callback_complain(none=>"linkrule for $feature") if $@;
-    return $val;
-  }
-
-  require CGI unless defined &CGI::escape;
-  my $n;
-  $linkrule ||= ''; # prevent uninit warning
-  $linkrule =~ s/\$(\w+)/
-    CGI::escape(
-    $1 eq 'ref'              ? (($n = $feature->location->seq_id) && "$n") || ''
-      : $1 eq 'name'         ? (($n = $feature->display_name) && "$n")     || ''
-      : $1 eq 'class'        ? eval {$feature->class}  || ''
-      : $1 eq 'type'         ? eval {$feature->method} || $feature->primary_tag || ''
-      : $1 eq 'method'       ? eval {$feature->method} || $feature->primary_tag || ''
-      : $1 eq 'source'       ? eval {$feature->source} || $feature->source_tag  || ''
-      : $1 eq 'start'        ? $feature->start || ''
-      : $1 eq 'end'          ? $feature->end   || ''
-      : $1 eq 'stop'         ? $feature->end   || ''
-      : $1 eq 'segstart'     ? $panel->start   || ''
-      : $1 eq 'segend'       ? $panel->end     || ''
-      : $1 eq 'description'  ? eval {join '',$feature->notes} || ''
-      : $1 eq 'id'           ? $feature->feature_id || ''
-      : $1
-       )
-	/exg;
-  return $linkrule;
-}
-
 sub make_link {
-  my $self             = shift;
-  my ($feature,$panel) = @_;
-
-  for my $label ($self->feature2label($feature)) {
-    my $linkrule     = $self->setting($label,'link');
-    $linkrule        = $self->setting(general=>'link') unless defined $linkrule;
-    return $self->link_pattern($linkrule,$feature,$panel);
-  }
+  my $self     = shift;
+  my $feature  = shift;
+  my $label    = $self->feature2label($feature) or return;
+  my $link     = $self->setting($label,'link');
+  $link        = $self->setting(general=>'link') unless defined $link;
+  return unless $link;
+  return $self->link_pattern($link,$feature);
 }
 
-sub make_title {
+sub link_pattern {
   my $self = shift;
-  my $feature = shift;
-
-  for my $label ($self->feature2label($feature)) {
-    my $linkrule     = $self->setting($label,'title');
-    $linkrule        ||= $self->setting(general=>'title');
-    next unless $linkrule;
-    return $self->link_pattern($linkrule,$feature);
-  }
-
-  my $method  = eval {$feature->method} || $feature->primary_tag;
-  my $seqid   = $feature->can('seq_id')      ? $feature->seq_id : $feature->location->seq_id;
-  my $title = eval {
-    if ($feature->can('target') && (my $target = $feature->target)) {
-      join (' ',
-	    $method,
-	    (defined $seqid ? "$seqid:" : '').
-	    $feature->start."..".$feature->end,
-	    $feature->target.':'.
-	    $feature->target->start."..".$feature->target->end);
-    } else {
-      join(' ',
-	   $method,
-	   $feature->can('display_name') ? $feature->display_name : $feature->info,
-	   (defined $seqid ? "$seqid:" : '').
-	   ($feature->start||'?')."..".($feature->end||'?')
-	  );
-    }
-  };
-  warn $@ if $@;
-  $title;
+  my ($pattern,$feature,$panel) = @_;
+  $pattern =~ s/\$(\w+)/
+    $1 eq 'ref'           ? $feature->location->seq_id
+      : $1 eq 'name'      ? $feature->display_name
+      : $1 eq 'class'     ? $feature->class
+      : $1 eq 'type'      ? $feature->method
+      : $1 eq 'method'    ? $feature->method
+      : $1 eq 'source'    ? $feature->source
+      : $1 eq 'start'     ? $feature->start
+      : $1 eq 'end'       ? $feature->end
+      : $1 eq 'segstart'  ? $panel->start
+      : $1 eq 'segend'    ? $panel->end
+      : $1
+       /exg;
+  return $pattern;
 }
 
-# given a feature type, return its label(s)
+# given a feature type, return its label
 sub type2label {
   my $self = shift;
   my $type = shift;
   $self->{_type2label} ||= $self->invert_types;
-  my @labels = keys %{$self->{_type2label}{$type}};
-  wantarray ? @labels : $labels[0]
+  $self->{_type2label}{$type};
 }
 
 sub invert_types {
@@ -1460,7 +1061,7 @@ sub invert_types {
   for my $label (keys %{$config}) {
     my $feature = $config->{$label}{feature} or next;
     foreach (shellwords($feature||'')) {
-      $inverted{$_}{$label}++;
+      $inverted{$_} = $label;
     }
   }
   \%inverted;
