@@ -1,13 +1,15 @@
 package Bio::Graphics::Glyph::transcript;
-# $Id: transcript.pm,v 1.23.4.1 2006/10/02 23:10:20 sendu Exp $
+# $Id: transcript.pm,v 1.12 2002/10/26 18:07:21 lstein Exp $
 
 use strict;
-use base qw(Bio::Graphics::Glyph::segments);
+use Bio::Graphics::Glyph::segments;
+use vars '@ISA';
+@ISA = qw( Bio::Graphics::Glyph::segments);
 
 sub pad_left  {
   my $self = shift;
-  return 0 unless $self->{level} == 0;
   my $pad  = $self->SUPER::pad_left;
+  return $pad if $self->{level} > 0;
   my $strand = $self->feature->strand;
   return $pad unless defined $strand && $strand < 0;
   return $self->arrow_length > $pad ? $self->arrow_length : $pad;
@@ -15,8 +17,8 @@ sub pad_left  {
 
 sub pad_right {
   my $self = shift;
-  return 0 unless $self->{level} == 0;
-  my $pad = $self->SUPER::pad_right;
+  my $pad  = $self->SUPER::pad_right;
+  return $pad if $self->{level} > 0;
   my $strand = $self->feature->strand;
   return $pad unless defined($strand) && $strand > 0;
   return $self->arrow_length > $pad ? $self->arrow_length : $pad;
@@ -28,53 +30,29 @@ sub draw_component {
   $self->SUPER::draw_component(@_);
 }
 
-sub part_label_merge {
-  my $self = shift;
-  my $label = $self->SUPER::part_label_merge;
-  return $label if defined $label;
-  1;
-}
-
 sub draw_connectors {
   my $self = shift;
   my $gd = shift;
   my ($left,$top) = @_;
-
   $self->SUPER::draw_connectors($gd,$left,$top);
-  my @parts = $self->parts; # or return;
+  my @parts = $self->parts;
 
   # H'mmm.  No parts.  Must be in an intron, so draw intron
   # spanning entire range
   if (!@parts) {
-    return unless $self->feature_has_subparts;
     my($x1,$y1,$x2,$y2) = $self->bounds(0,0);
     $self->_connector($gd,$left,$top,$x1,$y1,$x1,$y2,$x2,$y1,$x2,$y2);
-    @parts = ($self);
+    @parts = $self;
   }
 
-  # flip argument makes this confusing
-  # certainly there's a simpler way to express this idea
-  my $strand    = $self->feature->strand;
-  my ($first,$last) = ($parts[0],$parts[-1]);
-
-  ($first,$last) = ($last,$first) if exists $self->{flip};
-
-  if ($strand > 0) {
-    my($x1,$y1,$x2,$y2) = $last->bounds(@_);
+  if ($self->feature->strand >= 0) {
+    my($x1,$y1,$x2,$y2) = $parts[-1]->bounds(@_);
     my $center = ($y2+$y1)/2;
-    $self->{flip} ?
-	$self->arrow($gd,$x1,$x1-$self->arrow_length,$center)
-      :
-	$self->arrow($gd,$x2,$x2+$self->arrow_length,$center);
-  }
-
-  elsif ($strand < 0) {
-    my($x1,$y1,$x2,$y2) = $first->bounds(@_);
+    $self->arrow($gd,$x2,$x2+$self->arrow_length,$center);
+  } else {
+    my($x1,$y1,$x2,$y2) = $parts[0]->bounds(@_);
     my $center = ($y2+$y1)/2;
-    $self->{flip } ?
-	$self->arrow($gd,$x2,$x2+$self->arrow_length,$center)
-      :
-	$self->arrow($gd,$x1,$x1 - $self->arrow_length,$center);
+    $self->arrow($gd,$x1,$x1 - $self->arrow_length,$center);
   }
 }
 
@@ -87,7 +65,7 @@ sub arrow_length {
 sub connector {
   my $self = shift;
   return $self->SUPER::connector(@_) if $self->all_callbacks;
-  return ($self->option('connector') || 'hat');
+  return 'hat';
 }
 
 
@@ -141,8 +119,6 @@ L<Bio::Graphics::Glyph> for a full explanation.
 
   -description  Whether to draw a description  0 (false)
 
-  -hilite       Highlight color                undef (no color)
-
 In addition, the alignment glyph recognizes the following
 glyph-specific options:
 
