@@ -1,4 +1,4 @@
-# $Id: GOterm.pm,v 1.22.4.1 2006/10/02 23:10:22 sendu Exp $
+# $Id: GOterm.pm,v 1.12 2002/12/28 03:26:33 lapp Exp $
 #
 # BioPerl module for Bio::Ontology::GOterm
 #
@@ -23,7 +23,7 @@
 
 =head1 NAME
 
-Bio::Ontology::GOterm - representation of GO terms 
+GOterm - representation of GO terms 
 
 =head1 SYNOPSIS
 
@@ -46,8 +46,8 @@ Bio::Ontology::GOterm - representation of GO terms
 
 =head1 DESCRIPTION
 
-This is "dumb" class for GO terms (it provides no functionality 
-related to graphs). Implements Bio::Ontology::TermI.
+This is "dumb" class for GO terms (it provides no functionality related to graphs).
+Implements Bio::Ontology::TermI.
 
 =head1 FEEDBACK
 
@@ -57,15 +57,17 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to one
 of the Bioperl mailing lists.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+  bioperl-l@bioperl.org             - General discussion
+  http://bio.perl.org/MailList.html - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via the web:
+the bugs and their resolution.  Bug reports can be submitted via email
+or the web:
 
-  http://bugzilla.open-bio.org/
+  bioperl-bugs@bio.perl.org
+  http://bugzilla.bioperl.org/
 
 =head1 AUTHOR
 
@@ -92,13 +94,15 @@ methods.
 # Let the code begin...
 
 package Bio::Ontology::GOterm;
+use vars qw( @ISA );
 use strict;
+use Bio::Ontology::Term;
 
-use constant GOID_DEFAULT => "GO:0000000";
+use constant GOID_DEFAULT => "GO:-------";
 use constant TRUE         => 1;
 use constant FALSE        => 0;
 
-use base qw(Bio::Ontology::Term);
+@ISA = qw( Bio::Ontology::Term );
 
 
 
@@ -106,24 +110,22 @@ use base qw(Bio::Ontology::Term);
 =head2 new
 
  Title   : new
- Usage   : $term = Bio::Ontology::GOterm->new( 
-       -go_id       => "GO:0016847",
-       -name        => "1-aminocyclopropane-1-carboxylate synthase",
-       -definition  => "Catalysis of ...",
-       -is_obsolete => 0,
-       -comment     => "" );                   
+ Usage   : $term = Bio::Ontology::GOterm->new( -go_id       => "GO:0016847",
+                                               -name        => "1-aminocyclopropane-1-carboxylate synthase",
+                                               -definition  => "Catalysis of ...",
+                                               -is_obsolete => 0,
+                                               -comment     => "" );                   
  Function: Creates a new Bio::Ontology::GOterm.
  Returns : A new Bio::Ontology::GOterm object.
- Args    : -go_id         => the goid of this GO term [GO:nnnnnnn] 
-                             or [nnnnnnn] (nnnnnnn is a zero-padded
-                             integer of seven digits)
-           -name          => the name of this GO term [scalar]
-           -definition    => the definition of this GO term [scalar]  
-           -ontology      => the ontology for this term (a
-                             Bio::Ontology::OntologyI compliant object)
-           -version       => version information [scalar]
-           -is_obsolete   => the obsoleteness of this GO term [0 or 1]   
-           -comment       => a comment [scalar]
+ Args    : -go_id                 => the goid of this GO term [GO:nnnnnnn] 
+                                     or [nnnnnnn] (nnnnnnn is a zero-padded
+                                     integer of seven digits)
+           -name                  => the name of this GO term [scalar]
+           -definition            => the definition of this GO term [scalar]  
+           -category              => a relationship between this Term and another Term [TermI or scalar]
+           -version               => version information [scalar]
+           -is_obsolete           => the obsoleteness of this GO term [0 or 1]   
+           -comment               => a comment [scalar]
 
 =cut
 
@@ -144,6 +146,9 @@ sub new {
 } # new
 
 
+
+
+
 =head2 init
 
  Title   : init()
@@ -158,15 +163,18 @@ sub init {
 
     my $self = shift;
 
-    # first call the inherited version to properly chain up the hierarchy
     $self->SUPER::init(@_);
 
-    # then only initialize what we implement ourselves here
-    #$self->GO_id( GOID_DEFAULT );
+    $self->GO_id( GOID_DEFAULT );
+    $self->remove_dblinks();
+    $self->remove_secondary_GO_ids();
+    $self->remove_synonyms();
   
 } # init
 
 
+
+
 =head2 GO_id
 
  Title   : GO_id
@@ -198,36 +206,110 @@ sub GO_id {
 } # GO_id
 
 
-=head2 get_secondary_GO_ids
 
- Title   : get_secondary_GO_ids
- Usage   : @ids = $term->get_secondary_GO_ids();
+
+
+=head2 each_dblink
+
+ Title   : each_dblink()
+ Usage   : @ds = $term->each_dblink();                 
+ Function: Returns a list of each dblinks of this GO term.
+ Returns : A list of dblinks [array of [scalars]].
+ Args    :
+
+=cut
+
+sub each_dblink {
+    my ( $self ) = @_;
+    
+    if ( $self->{ "_dblinks" } ) {
+        return @{ $self->{ "_dblinks" } };
+    }
+    else {
+        return my @a = (); 
+    }
+    
+} # each_dblink
+
+
+=head2 add_dblinks
+
+ Title   : add_dblinks
+ Usage   : $term->add_dblinks( @dbls );
+           or
+           $term->add_dblinks( $dbl );                  
+ Function: Pushes one or more dblinks
+           into the list of dblinks.
+ Returns : 
+ Args    : One  dblink [scalar] or a list of
+            dblinks [array of [scalars]].
+
+=cut
+
+sub add_dblinks {
+    my ( $self, @values ) = @_;
+    
+    return unless( @values );
+        
+    push( @{ $self->{ "_dblinks" } }, @values );
+    
+} # add_dblinks
+
+
+=head2 remove_dblinks
+
+ Title   : remove_dblinks()
+ Usage   : $term->remove_dblinks();
+ Function: Deletes (and returns) the definition references of this GO term.
+ Returns : A list of definition references [array of [scalars]].
+ Args    :
+
+=cut
+
+sub remove_dblinks {
+    my ( $self ) = @_;
+     
+    my @a = $self->each_dblink();
+    $self->{ "_dblinks" } = [];
+    return @a;
+
+} # remove_dblinks
+
+
+
+
+=head2 each_secondary_GO_id
+
+ Title   : each_secondary_GO_id()
+ Usage   : @ids = $term->each_secondary_GO_id();                 
  Function: Returns a list of secondary goids of this Term.
-
-           This is aliased to remove_secondary_ids().
-
  Returns : A list of secondary goids [array of [GO:nnnnnnn]]
            (nnnnnnn is a zero-padded integer of seven digits).
  Args    :
 
 =cut
 
-sub get_secondary_GO_ids {
-    return shift->get_secondary_ids(@_);
-} # get_secondary_GO_ids
+sub each_secondary_GO_id {
+    my ( $self ) = @_;
+    
+    if ( $self->{ "_secondary_GO_ids" } ) {
+        return @{ $self->{ "_secondary_GO_ids" } };
+    }
+    else {
+        return my @a = (); 
+    }
+    
+} # each_secondary_GO_id
 
 
-=head2 add_secondary_GO_id
+=head2 add_secondary_GO_ids
 
- Title   : add_secondary_GO_id
- Usage   : $term->add_secondary_GO_id( @ids );
+ Title   : add_secondary_GO_ids
+ Usage   : $term->add_secondary_GO_ids( @ids );
            or
-           $term->add_secondary_GO_id( $id );                  
+           $term->add_secondary_GO_ids( $id );                  
  Function: Pushes one or more secondary goids into
            the list of secondary goids.
-
-           This is aliased to remove_secondary_ids().
-
  Returns : 
  Args    : One secondary goid [GO:nnnnnnn or nnnnnnn] or a list
            of secondary goids [array of [GO:nnnnnnn or nnnnnnn]]
@@ -235,9 +317,18 @@ sub get_secondary_GO_ids {
 
 =cut
 
-sub add_secondary_GO_id {
-    return shift->add_secondary_id(@_);
-} # add_secondary_GO_id
+sub add_secondary_GO_ids {
+    my ( $self, @values ) = @_;
+    
+    return unless( @values );
+    
+    foreach my $value ( @values ) {  
+        $value = $self->_check_go_id( $value );
+    }
+    
+    push( @{ $self->{ "_secondary_GO_ids" } }, @values );
+    
+} # add_secondary_GO_ids
 
 
 =head2 remove_secondary_GO_ids
@@ -245,9 +336,6 @@ sub add_secondary_GO_id {
  Title   : remove_secondary_GO_ids()
  Usage   : $term->remove_secondary_GO_ids();
  Function: Deletes (and returns) the secondary goids of this Term.
-
-           This is aliased to remove_secondary_ids().
-
  Returns : A list of secondary goids [array of [GO:nnnnnnn]]
            (nnnnnnn is a zero-padded integer of seven digits).
  Args    :
@@ -255,10 +343,17 @@ sub add_secondary_GO_id {
 =cut
 
 sub remove_secondary_GO_ids {
-    return shift->remove_secondary_ids(@_);
+    my ( $self ) = @_;
+     
+    my @a = $self->each_secondary_GO_id();
+    $self->{ "_secondary_GO_ids" } = [];
+    return @a;
+
 } # remove_secondary_GO_ids
 
 
+
+
 =head2 to_string
 
  Title   : to_string()
@@ -275,14 +370,14 @@ sub to_string {
     my $s = "";
 
     $s .= "-- GO id:\n";
-    $s .= ($self->GO_id() || '')."\n";
+    $s .= $self->GO_id()."\n";
     $s .= "-- Name:\n";
     $s .= ($self->name() || '') ."\n";
     $s .= "-- Definition:\n";
     $s .= ($self->definition() || '') ."\n";
     $s .= "-- Category:\n";
-    if ( defined( $self->ontology() ) ) {
-        $s .= $self->ontology()->name()."\n";
+    if ( defined( $self->category() ) ) {
+        $s .= $self->category()->name()."\n";
     }
     else {
         $s .= "\n";
@@ -294,11 +389,11 @@ sub to_string {
     $s .= "-- Comment:\n";
     $s .= ($self->comment() || '') ."\n"; 
     $s .= "-- Definition references:\n";
-    $s .= $self->_array_to_string( $self->get_dblinks() )."\n";
+    $s .= $self->_array_to_string( $self->each_dblink() )."\n";
     $s .= "-- Secondary GO ids:\n";
-    $s .= $self->_array_to_string( $self->get_secondary_GO_ids() )."\n";
+    $s .= $self->_array_to_string( $self->each_secondary_GO_id() )."\n";
     $s .= "-- Aliases:\n";
-    $s .= $self->_array_to_string( $self->get_synonyms() );
+    $s .= $self->_array_to_string( $self->each_synonym() );
     
     return $s;
     
@@ -345,11 +440,5 @@ sub _array_to_string {
     
 } # _array_to_string
 
-#################################################################
-# aliases or forwards to maintain backward compatibility
-#################################################################
-
-*each_secondary_GO_id = \&get_secondary_GO_ids;
-*add_secondary_GO_ids = \&add_secondary_GO_id;
 
 1;
