@@ -1,4 +1,4 @@
-# $Id: TermI.pm,v 1.17.4.1 2006/10/02 23:10:22 sendu Exp $
+# $Id: TermI.pm,v 1.8 2002/12/12 18:27:00 czmasek Exp $
 #
 # BioPerl module for Bio::Ontology::Term
 #
@@ -20,9 +20,10 @@
 
 # POD documentation - main docs before the code
 
+
 =head1 NAME
 
-Bio::Ontology::TermI - interface for ontology terms
+TermI - interface for ontology terms
 
 =head1 SYNOPSIS
 
@@ -34,7 +35,7 @@ Bio::Ontology::TermI - interface for ontology terms
   print $term->is_obsolete(), "\n";
   print $term->comment(), "\n";
 
-  foreach my $synonym ( $term->get_synonyms() ) {
+  foreach my $synonym ( $term->each_synonym() ) {
       print $synonym, "\n";
   }
 
@@ -52,16 +53,17 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to one
 of the Bioperl mailing lists.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+  bioperl-l@bioperl.org             - General discussion
+  http://bio.perl.org/MailList.html - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via
-the web:
+the bugs and their resolution.  Bug reports can be submitted via email
+or the web:
 
-  http://bugzilla.open-bio.org/
+  bioperl-bugs@bio.perl.org
+  http://bugzilla.bioperl.org/
 
 =head1 AUTHOR
 
@@ -88,9 +90,11 @@ methods.
 # Let the code begin...
 
 package Bio::Ontology::TermI;
+use vars qw( @ISA );
 use strict;
+use Bio::Root::Object;
 
-use base qw(Bio::Root::RootI);
+@ISA = qw( Bio::Root::Root );
 
 
 
@@ -107,7 +111,10 @@ use base qw(Bio::Root::RootI);
 =cut
 
 sub identifier {
-    shift->throw_not_implemented();
+    my ( $self ) = @_;
+    
+    $self->throw_not_implemented();
+
 } # identifier
 
 
@@ -126,7 +133,10 @@ sub identifier {
 =cut
 
 sub name {
-    shift->throw_not_implemented();
+    my ( $self ) = @_;
+    
+    $self->throw_not_implemented();
+
 } # name
 
 
@@ -146,40 +156,34 @@ sub name {
 =cut
 
 sub definition {
-    shift->throw_not_implemented();
+    my ( $self ) = @_;
+    
+    $self->throw_not_implemented();
+
 } # definition
 
 
 
-=head2 ontology
+=head2 category
 
- Title   : ontology
- Usage   : $ont = $term->ontology();
+ Title   : category
+ Usage   : $term->category( $top );
            or 
-           $term->ontology( $ont );
- Function: Get the ontology this term is in.
-
-           An implementation may not permit the value of this
-           attribute to be changed once it is set, since that may have
-           serious consequences (note that with the ontology in hand
-           you can query for all related terms etc).
-
-           Note for implementors: you will almost certainly have to
-           take special precaution in order not to create cyclical
-           references in memory.
-
- Returns : The ontology of this Term as a Bio::Ontology::OntologyI
-           implementing object.
- Args    : On set, the  ontology of this Term as a Bio::Ontology::OntologyI
-           implementing object or a string representing its name.
-
-See L<Bio::Ontology::OntologyI>.
+           $top = $term->category();
+ Function: Set/get for a relationship between this Term and
+           another Term (e.g. the top level of the ontology).
+ Returns : The category of this Term [TermI].
+ Args    : The category of this Term [TermI or scalar -- which
+           becomes the name of the catagory term] (optional).
 
 =cut
 
-sub ontology {
-    shift->throw_not_implemented();
-} # ontology
+sub category {
+    my ( $self ) = @_;
+    
+    $self->throw_not_implemented();
+    
+} # category
 
 
 
@@ -196,7 +200,10 @@ sub ontology {
 =cut
 
 sub version {
-    shift->throw_not_implemented();
+    my ( $self ) = @_;
+    
+    $self->throw_not_implemented();
+    
 } # version
 
 
@@ -215,7 +222,10 @@ sub version {
 =cut
 
 sub is_obsolete {
-    shift->throw_not_implemented();
+    my ( $self ) = @_;
+    
+    $self->throw_not_implemented();
+    
 } # is_obsolete
 
 
@@ -233,120 +243,69 @@ sub is_obsolete {
 =cut
 
 sub comment {
-    shift->throw_not_implemented();
+    my ( $self ) = @_;
+    
+    $self->throw_not_implemented();
+    
 } # comment
 
 
 
 
-=head2 get_synonyms
+=head2 each_synonym
 
- Title   : get_synonyms
- Usage   : @aliases = $term->get_synonyms();
+ Title   : each_synonym()
+ Usage   : @aliases = $term->each_synonym();                 
  Function: Returns a list of aliases of this Term.
-
-           If an implementor of this interface permits modification of
-           this array property, the class should define at least
-           methods add_synonym() and remove_synonyms(), with obvious
-           functionality.
-
  Returns : A list of aliases [array of [scalar]].
  Args    :
 
 =cut
 
-sub get_synonyms {
-    shift->throw_not_implemented();
-} # get_synonyms
+sub each_synonym {
+    my ( $self ) = @_;
+    
+    $self->throw_not_implemented();
 
-=head2 get_dblinks
+} # each_synonym
 
- Title   : get_dblinks()
- Usage   : @ds = $term->get_dblinks();
- Function: Returns a list of each dblink of this term.
 
-           If an implementor of this interface permits modification of
-           this array property, the class should define at least
-           methods add_dblink() and remove_dblinks(), with obvious
-           functionality.
+=head2 add_synonyms
 
- Returns : A list of dblinks [array of [scalars]].
+ Title   : add_synonyms
+ Usage   : $term->add_synonyms( @asynonyms );
+           or
+           $term->add_synonyms( $synonym );                  
+ Function: Pushes one or more synonyms into the list of synonyms.
+ Returns : 
+ Args    : One synonym [scalar] or a list of synonyms [array of [scalar]].
+
+=cut
+
+sub add_synonyms {
+    my ( $self ) = @_;
+    
+    $self->throw_not_implemented();
+
+} # add_synonyms
+
+
+=head2 remove_synonyms
+
+ Title   : remove_synonyms()
+ Usage   : $term->remove_synonyms();
+ Function: Deletes (and returns) the synonyms of this Term.
+ Returns : A list of synonyms [array of [scalar]].
  Args    :
 
 =cut
 
-sub get_dblinks {
-    shift->throw_not_implemented();
-} # get_dblinks
+sub remove_synonyms {
+    my ( $self ) = @_;
+    
+    $self->throw_not_implemented();
 
-=head2 get_secondary_ids
+} # remove_synonyms
 
- Title   : get_secondary_ids
- Usage   : @ids = $term->get_secondary_ids();
- Function: Returns a list of secondary identifiers of this Term.
-
-           Secondary identifiers mostly originate from merging terms,
-           or possibly also from splitting terms.
-
-           If an implementor of this interface permits modification of
-           this array property, the class should define at least
-           methods add_secondary_id() and remove_secondary_ids(), with
-           obvious functionality.
-
- Returns : A list of secondary identifiers [array of [scalar]]
- Args    :
-
-=cut
-
-sub get_secondary_ids {
-    shift->throw_not_implemented();
-} # get_secondary_ids
-
-
-=head1  Deprecated methods
-
-Used for looking up the methods that supercedes them.
-
-=cut
-
-=head2 category
-
- Title   : category
- Usage   :
- Function: This method is deprecated. Use ontology() instead. We provide
-           an implementation here that preserves backwards compatibility,
-           but if you do not have legacy code using it you should not be
-           calling this method.
- Example :
- Returns :
- Args    :
-
-=cut
-
-sub category {
-    my $self = shift;
-
-    $self->warn("TermI::category is deprecated and being phased out. ".
-		"Use TermI::ontology instead.");
-
-    # called in set mode?
-    if(@_) {
-	# yes; what is incompatible with ontology() is if we were given
-	# a TermI object
-	my $arg = shift;
-	$arg = $arg->name() if ref($arg) && $arg->isa("Bio::Ontology::TermI");
-	return $self->ontology($arg,@_);
-    } else {
-	# No, called in get mode. This is always incompatible with ontology()
-	# since category is supposed to return a TermI.
-	my $ont = $self->ontology();
-	my $term;
-	if(defined($ont)) {
-	    $term = Bio::Ontology::Term->new(-name => $ont->name(),
-					     -identifier =>$ont->identifier());
-	}
-	return $term;
-    }
-} # category
 
 1;
