@@ -1,4 +1,4 @@
-# $Id: PrimarySeqI.pm,v 1.50.2.3 2003/08/29 15:37:39 birney Exp $
+# $Id: PrimarySeqI.pm,v 1.50 2002/12/24 12:14:13 birney Exp $
 #
 # BioPerl module for Bio::PrimarySeqI
 #
@@ -371,6 +371,7 @@ are encouraged to override these methods
 sub revcom{
    my ($self) = @_;
 
+
    # check the type is good first.
    my $t = $self->alphabet;
 
@@ -418,8 +419,7 @@ sub revcom{
 			     '-display_id'  => $self->display_id,
 			     '-accession_number' => $self->accession_number,
 			     '-alphabet' => $self->alphabet,
-			     '-desc' => $self->desc(),
-                             '-verbose' => $self->verbose
+			     '-desc' => $self->desc()
 			     );
    return $out;
 
@@ -468,12 +468,12 @@ sub trunc{
 			     '-display_id'  => $self->display_id,
 			     '-accession_number' => $self->accession_number,
 			     '-alphabet' => $self->alphabet,
-			     '-desc' => $self->desc(),
-                             '-verbose' => $self->verbose
+			     '-desc' => $self->desc()
 			     );
    return $out;
 }
 
+
 =head2 translate
 
  Title   : translate
@@ -500,17 +500,13 @@ sub trunc{
            frame (optional) valid values 0, 1, 2, defaults to 0
            codon table id (optional) defaults to 1
            complete coding sequence expected, defaults to 0 (false)
-           boolean, throw exception if not complete CDS (true) or defaults to
-warning (false)
-           coding sequence expected to be complete at 5', defaults to false
-           coding sequence expected to be complete at 3', defaults to false
+           boolean, throw exception if not complete CDS (true) or defaults to warning (false)
 
 =cut
 
 sub translate {
     my($self) = shift;
-    my($stop, $unknown, $frame, $tableid, $fullCDS, $throw, $complete5,
-$complete3) = @_;
+    my($stop, $unknown, $frame, $tableid, $fullCDS, $throw) = @_;
     my($i, $len, $output) = (0,0,'');
     my($codon)   = "";
     my $aa;
@@ -546,49 +542,33 @@ $complete3) = @_;
     # Use user-input stop/unknown
     $output =~ s/\*/$stop/g;
     $output =~ s/X/$unknown/g;
-
-    # $complete5 and $complete3 indicate completeness of
-    # the coding sequence at the 5' and 3' ends. Complete
-    # if true, default to false. These are in addition to
-    # $fullCDS, for backwards compatibility
-    defined($complete5) or ($complete5 = $fullCDS ? 1 : 0);
-    defined($complete3) or ($complete3 = $fullCDS ? 1 : 0);
-
-    my $id = $self->display_id;
-
-    # only if we are expecting to be complete at the 5' end
-    if($complete5) {
-	# if the initiator codon is not ATG, the amino acid needs to changed into M
-	if(substr($output,0,1) ne 'M') {
-	    if($codonTable->is_start_codon(substr($seq, 0, 3)) ) {
-		$output = 'M' . substr($output, 1);
-	    }
-	    elsif($throw) {
-		$self->throw("Seq [$id]: Not using a valid initiator codon!");
-	    } else {
-		$self->warn("Seq [$id]: Not using a valid initiator codon!");
-	    }
-	}
-    }
-
-    # only if we are expecting to be complete at the 3' end
-    if($complete3) {
+	
+    # only if we are expecting to translate a complete coding region
+    if ($fullCDS) {
+	my $id = $self->display_id;
 	#remove the stop character
-	if(substr($output, -1, 1) eq $stop) {
+	if( substr($output,-1,1) eq $stop ) {
 	    chop $output;
 	} else {
 	    $throw && $self->throw("Seq [$id]: Not using a valid terminator codon!");
 	    $self->warn("Seq [$id]: Not using a valid terminator codon!");
 	}
-    }
-
-    # only if we are expecting to translate a complete coding region
-    if($complete5 and $complete3) {
 	# test if there are terminator characters inside the protein sequence!
-	if($output =~ /\*/) {
+	if ($output =~ /\*/) {
 	    $throw && $self->throw("Seq [$id]: Terminator codon inside CDS!");
 	    $self->warn("Seq [$id]: Terminator codon inside CDS!");
 	}
+	# if the initiator codon is not ATG, the amino acid needs to changed into M
+	if ( substr($output,0,1) ne 'M' ) {
+	    if ($codonTable->is_start_codon(substr($seq, 0, 3)) ) {
+		$output = 'M'. substr($output,1);
+	    }
+	    elsif ($throw) {
+		$self->warn("Seq [$id]: Not using a valid initiator codon!");
+	    } else {
+		$self->throw("Seq [$id]: Not using a valid initiator codon!");
+	    }
+	}
     }
 
     my $seqclass;
@@ -604,8 +584,7 @@ $complete3) = @_;
 			      # is there anything wrong with retaining the
 			      # description?
 			      '-desc' => $self->desc(),
-			      '-alphabet' => 'protein',
-                              '-verbose' => $self->verbose
+			      '-alphabet' => 'protein'
 			      );
     return $out;
 
@@ -625,7 +604,9 @@ $complete3) = @_;
 =cut
 
 sub  id {
-   return shift->display_id();
+   my ($self)= @_;
+
+   return $self->display_id();
 }
 
 
@@ -642,7 +623,8 @@ sub  id {
 =cut
 
 sub  length {
-   shift->throw_not_implemented();
+   my ($self)= @_;
+   $self->throw_not_implemented();
 }
 
 =head2 desc
@@ -675,7 +657,11 @@ sub desc {
 =cut
 
 sub is_circular{
-    shift->throw_not_implemented();
+    my ($self,$value) = @_;
+    if (defined $value) {
+	$self->{'_is_circular'} = $value;
+    }
+    return $self->{'_is_circular'};
 }
 
 =head1 Private functions
