@@ -1,4 +1,4 @@
-# $Id$
+# $Id: IO.pm,v 1.37 2002/12/01 00:09:11 jason Exp $
 #
 # BioPerl module for Bio::Root::IO
 #
@@ -54,13 +54,6 @@ platforms. At present, File::Spec and File::Temp are attempted. This
 module defines $PATHSEP, $TEMPDIR, and $ROOTDIR, which will always be set, 
 and $OPENFLAGS, which will be set if either of File::Spec or File::Temp fails.
 
-The -noclose boolean (accessed via the noclose method) prevents a
-filehandle from being closed when the IO object is cleaned up.  This
-is special behavior when a object like a parser might share a
-filehandle with an object like an indexer where it is not proper to
-close the filehandle as it will continue to be reused until the end of the
-stream is reached.  In general you won't want to play with this flag.
-
 =head1 FEEDBACK
 
 =head2 Mailing Lists
@@ -218,15 +211,10 @@ sub new {
 
  Title   : initialize_io
  Usage   : $self->_initialize_io(@params);
- Function: Initializes filehandle and other properties from the parameters.
+ Function: Initializes filehandle and other properties.
 
-           Currently recognizes the following named parameters:
-              -file     name of file to open
-              -input    name of file, or GLOB, or IO::Handle object
-              -fh       file handle (mutually exclusive with -file)
-              -flush    boolean flag to autoflush after each write
-              -noclose  boolean flag, when set to true will not close a
-                        filehandle (must explictly call close($io->_fh)
+           Currently recognized the following named parameters: -file, -fh
+ Example :
  Returns : TRUE
  Args    : named parameters
 
@@ -238,14 +226,13 @@ sub _initialize_io {
 
     $self->_register_for_cleanup(\&_io_cleanup);
 
-    my ($input, $noclose, $file, $fh, $flush) = $self->_rearrange([qw(INPUT 
-							    NOCLOSE
+    my ($input, $file, $fh, $flush) = $self->_rearrange([qw(INPUT 
 							    FILE FH 
 							    FLUSH)], @args);
     
     delete $self->{'_readbuffer'};
     delete $self->{'_filehandle'};
-    $self->noclose( $noclose) if defined $noclose;
+
     # determine whether the input is a file(name) or a stream
     if($input) {
 	if(ref(\$input) eq "SCALAR") {
@@ -271,7 +258,7 @@ sub _initialize_io {
     if(defined($file) && ($file ne '')) {
 	$fh = Symbol::gensym();
 	open ($fh,$file) ||
-	    $self->throw("Could not open $file: $!");
+	    $self->throw("Could not open $file for reading: $!");
 	$self->file($file);
     }
     $self->_fh($fh) if $fh; # if not provided, defaults to STDIN and STDOUT
@@ -285,7 +272,7 @@ sub _initialize_io {
 
  Title   : _fh
  Usage   : $obj->_fh($newval)
- Function: Get/set the file handle for the stream encapsulated.
+ Function:
  Example :
  Returns : value of _filehandle
  Args    : newvalue (optional)
@@ -346,9 +333,6 @@ sub mode {
 
       if($^O eq 'linux'){
         $obj->{'_mode'} = 'r';
-        my $line = $iotest->getline;
-        $obj->_pushback($line) if defined $line;
-        $obj->{'_mode'} = defined $line ? 'r' : 'w';
         return $obj->{'_mode'};
       } else {
         my $line = $iotest->getline;
@@ -375,7 +359,7 @@ sub mode {
 
  Title   : file
  Usage   : $obj->file($newval)
- Function: Get/set the filename, if one has been designated.
+ Function:
  Example :
  Returns : value of file
  Args    : newvalue (optional)
@@ -403,7 +387,7 @@ sub file {
 
 sub _print {
     my $self = shift;
-    my $fh = $self->_fh() || \*STDOUT;
+    my $fh = $self->_fh || \*STDOUT;
     print $fh @_;
 }
 
@@ -432,14 +416,15 @@ sub _print {
 sub _readline {
     my $self = shift;
     my %param =@_;
-    my $fh = $self->_fh || \*ARGV;
+
+    my $fh = $self->_fh || \*STDIN;
     my $line;
 
     # if the buffer been filled by _pushback then return the buffer
     # contents, rather than read from the filehandle
-    $line = shift @{$self->{'_readbuffer'}} || <$fh>;
+	$line = shift @{$self->{'_readbuffer'}} || <$fh>;
 
-    #don't strip line endings if -raw is specified
+    #don't stip line endings if -raw is specified
     $line =~ s/\r\n/\n/g if( (!$param{-raw}) && (defined $line) );
 
     return $line;
@@ -469,26 +454,15 @@ sub _pushback {
  Title   : close
  Usage   : $io->close()
  Function: Closes the file handle associated with this IO instance.
-           Will not close the FH if  -noclose is specified
- Returns : none
- Args    : none
+ Example :
+ Returns :
+ Args    :
 
 =cut
 
 sub close {
-   my ($self) = @_;
-   return if $self->noclose; # don't close if we explictly asked not to
-   if( defined $self->{'_filehandle'} ) {
-       $self->flush;
-       return if( \*STDOUT == $self->_fh ||
-		  \*STDERR == $self->_fh ||
-		  \*STDIN == $self->_fh
-		  ); # don't close STDOUT fh
-       if( ! ref($self->{'_filehandle'}) ||
-	   ! $self->{'_filehandle'}->isa('IO::String') ) {
-	   close($self->{'_filehandle'});
-       }
-   }
+   my ($self, @args) = @_;
+
    $self->{'_filehandle'} = undef;
    delete $self->{'_readbuffer'};
 }
@@ -499,8 +473,9 @@ sub close {
  Title   : flush
  Usage   : $io->flush()
  Function: Flushes the filehandle
- Returns : none
- Args    : none
+ Example :
+ Returns :
+ Args    :
 
 =cut
 
@@ -520,37 +495,17 @@ sub flush {
   }
 }
   
-=head2 noclose
 
- Title   : noclose
- Usage   : $obj->noclose($newval)
- Function: Get/Set the NOCLOSE flag - setting this to true will
-           prevent a filehandle from being closed
-           when an object is cleaned up or explicitly closed
-           This is a bit of hack 
- Returns : value of noclose (a scalar)
- Args    : on set, new value (a scalar or undef, optional)
-
-
-=cut
-
-sub noclose{
-    my $self = shift;
-
-    return $self->{'_noclose'} = shift if @_;
-    return $self->{'_noclose'};
-}
 
 sub _io_cleanup {
     my ($self) = @_;
 
     $self->close();
-    my $v = $self->verbose;
 
     # we are planning to cleanup temp files no matter what    
     if( exists($self->{'_rootio_tempfiles'}) &&
 	ref($self->{'_rootio_tempfiles'}) =~ /array/i) { 
-	if( $v > 0 ) {
+	if( $self->verbose > 0 ) {
 	    print STDERR "going to remove files ", 
 	    join(",",  @{$self->{'_rootio_tempfiles'}}), "\n";
 	}
@@ -561,7 +516,7 @@ sub _io_cleanup {
 	exists($self->{'_rootio_tempdirs'}) &&
 	ref($self->{'_rootio_tempdirs'}) =~ /array/i) {	
 
-	if( $v > 0 ) {
+	if( $self->verbose > 0 ) {
 	    print STDERR "going to remove dirs ", 
 	    join(",",  @{$self->{'_rootio_tempdirs'}}), "\n";
 	}
