@@ -1,4 +1,4 @@
-# $Id: ace.pm,v 1.17.4.1 2006/10/02 23:10:28 sendu Exp $
+# $Id: ace.pm,v 1.15 2002/10/25 16:23:16 jason Exp $
 #
 # BioPerl module for Bio::SeqIO::ace
 #
@@ -36,20 +36,22 @@ considered necessary.
 
 =head2 Mailing Lists
 
-User feedback is an integral part of the evolution of this and other
-Bioperl modules. Send your comments and suggestions preferably to one
-of the Bioperl mailing lists.  Your participation is much appreciated.
+User feedback is an integral part of the evolution of this
+and other Bioperl modules. Send your comments and suggestions preferably
+ to one of the Bioperl mailing lists.
+Your participation is much appreciated.
 
   bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+  http://www.bioperl.org/MailList.shtml  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.
-Bug reports can be submitted via the web:
+ the bugs and their resolution.
+ Bug reports can be submitted via email or the web:
 
-  http://bugzilla.open-bio.org/
+  bioperl-bugs@bio.perl.org
+  http://bugzilla.bioperl.org/
 
 =head1 AUTHORS - James Gilbert
 
@@ -67,17 +69,19 @@ methods. Internal methods are usually preceded with a _
 
 package Bio::SeqIO::ace;
 use strict;
+use vars qw(@ISA);
 
+use Bio::SeqIO;
 use Bio::Seq;
 use Bio::Seq::SeqFactory;
 
-use base qw(Bio::SeqIO);
+@ISA = qw(Bio::SeqIO);
 
 sub _initialize {
   my($self,@args) = @_;
-  $self->SUPER::_initialize(@args);
+  $self->SUPER::_initialize(@args);   
   if( ! defined $self->sequence_factory ) {
-      $self->sequence_factory(new Bio::Seq::SeqFactory(-verbose => $self->verbose(), -type => 'Bio::PrimarySeq'));
+      $self->sequence_factory(new Bio::Seq::SeqFactory(-verbose => $self->verbose(), -type => 'Bio::PrimarySeq'));      
   }
 }
 
@@ -96,7 +100,7 @@ sub _initialize {
         'dna'       => 'dna',
         'peptide'   => 'protein',
     );
-
+    
     sub next_seq {
         my( $self ) = @_;
         local $/ = "";  # Split input on blank lines
@@ -112,14 +116,14 @@ sub _initialize {
         }
         # Return if there weren't any DNA or peptide objects
         return unless $type;
-
+        
         # Choose the molecule type
         my $mol_type = $bio_mol_type{lc $type}
             or $self->throw("Can't get Bio::Seq molecule type for '$type'");
 
         # Remove quotes from $id
         $id =~ s/^"|"$//g;
-
+        
         # Un-escape forward slashes, double quotes, percent signs,
         # semi-colons, tabs, and backslashes (if you're mad enough
         # to have any of these as part of object names in your acedb
@@ -132,7 +136,7 @@ sub _initialize {
 					       -primary_id => $id,
 					       -display_id => $id,
 					       -alphabet    => $mol_type,
-					       );
+					       );        
     }
 }
 
@@ -149,19 +153,19 @@ sub _initialize {
 
 sub write_seq {
     my ($self, @seq) = @_;
-
+    
     foreach my $seq (@seq) {
-	$self->throw("Did not provide a valid Bio::PrimarySeqI object")
+	$self->throw("Did not provide a valid Bio::PrimarySeqI object") 
 	    unless defined $seq && ref($seq) && $seq->isa('Bio::PrimarySeqI');
         my $mol_type = $seq->alphabet;
         my $id = $seq->display_id;
-
+        
         # Escape special charachers in id
         $id =~ s/([\/"%;\t\\])/\\$1/g;
-#"
+#"        
         # Print header for DNA or Protein object
         if ($mol_type eq 'dna') {
-            $self->_print(
+            $self->_print( 
                 qq{\nSequence : "$id"\nDNA "$id"\n},
                 qq{\nDNA : "$id"\n},
             );
