@@ -1,4 +1,4 @@
-# $Id: BPlite.pm,v 1.42.4.1 2006/10/02 23:10:31 sendu Exp $
+# $Id: BPlite.pm,v 1.36 2002/10/08 10:10:05 birney Exp $
 ##############################################################################
 # Bioperl module Bio::Tools::BPlite
 ##############################################################################
@@ -27,7 +27,6 @@ Bio::Tools::BPlite - Lightweight BLAST parser
 	    $hsp->bits;
 	    $hsp->percent;
 	    $hsp->P;
-            $hsp->EXP;
 	    $hsp->match;
 	    $hsp->positive;
 	    $hsp->length;
@@ -94,11 +93,11 @@ have one attribute (name) and one method (nextHSP).
      # canonical form is again a while loop
  }
 
-An HSP is a high scoring pair, or simply an alignment.  HSP objects
-inherit all the useful methods from RangeI/SeqFeatureI/FeaturePair,
-but provide an additional set of attributes (score, bits, percent, P,
-match, EXP, positive, length, querySeq, sbjctSeq, homologySeq) that
-should be familiar to anyone who has seen a blast report.
+An HSP is a high scoring pair, or simply an alignment. 
+HSP objects inherit all the useful methods from RangeI/SeqFeatureI/FeaturePair,
+but provide an additional set of attributes (score, bits, percent, P, match, 
+positive, length, querySeq, sbjctSeq, homologySeq) that should be familiar to
+anyone who has seen a blast report. 
 
 For lazy/efficient coders, two-letter abbreviations are available for the 
 attributes with long names (qs, ss, hs). Ranges of the aligned sequences in
@@ -173,11 +172,15 @@ This software is provided "as is" without warranty of any kind.
 package Bio::Tools::BPlite;
 
 use strict;
+use vars qw(@ISA);
 
+use Bio::Root::Root;
+use Bio::Root::IO;
 use Bio::Tools::BPlite::Sbjct; # we want to use Sbjct
+use Bio::SeqAnalysisParserI;
 use Symbol;
 
-use base qw(Bio::Root::Root Bio::SeqAnalysisParserI Bio::Root::IO);
+@ISA = qw(Bio::Root::Root Bio::SeqAnalysisParserI Bio::Root::IO);
 
 # new comes from a RootI now
 
@@ -194,8 +197,7 @@ use base qw(Bio::Root::Root Bio::SeqAnalysisParserI Bio::Root::IO);
 sub new {
   my ($class, @args) = @_; 
   my $self = $class->SUPER::new(@args);
-    $self->warn("Use of Bio::Tools::BPlite is deprecated".
-                   "Use Bio::SearchIO classes instead");
+
   # initialize IO
   $self->_initialize_io(@args);
 
@@ -230,7 +232,7 @@ sub next_feature{
    $sbjct = $self->{'_current_sbjct'};
    unless( defined $sbjct ) {
        $sbjct = $self->{'_current_sbjct'} = $self->nextSbjct;
-       return  unless defined $sbjct;
+       return undef unless defined $sbjct;
    }   
    $hsp = $sbjct->nextHSP;
    unless( defined $hsp ) {
@@ -315,36 +317,27 @@ sub database {shift->{'DATABASE'}}
 sub nextSbjct {
   my ($self) = @_;
   
-  $self->_fastForward or return;
-  local $_;
+  $self->_fastForward or return undef;
+  
   #######################
   # get all sbjct lines #
   #######################
   my $def = $self->_readline();  
   while(defined ($_ = $self->_readline() ) ) {
-    if    (! /\w/)           {next}
-    elsif (/Strand HSP/o)    {next} # WU-BLAST non-data
-    elsif (/^\s{0,2}Score/o) {$self->_pushback($_); last}
-    elsif (/^Histogram|^Searching|^Parameters|
-            ^\s+Database:|
-            ^\s+Posted date:/ox) {
+    if    ($_ !~ /\w/)            {next}
+    elsif ($_ =~ /Strand HSP/)    {next} # WU-BLAST non-data
+    elsif ($_ =~ /^\s{0,2}Score/) {$self->_pushback($_); last}
+    elsif ($_ =~ /^Parameters|^\s+Database:|^\s+Posted date:/) {
 	$self->_pushback($_); 
 	last;
-    } else {
-	$def .= $_;
     }
-  }
-  if( ! $def ) { 
-      return;
+    else                          {$def .= $_}
   }
   $def =~ s/\s+/ /g;
   $def =~ s/\s+$//g;
-  
-  my $length;
-  if( $def =~ s/Length = ([\d,]+)$//g ) {
-      $length = $1;
-  }
-  return unless $def =~ /^>/;
+  $def =~ s/Length = ([\d,]+)$//g;
+  my $length = $1;
+  return undef unless $def =~ /^>/;
   $def =~ s/^>//;
 
   ####################
@@ -371,26 +364,18 @@ sub _parseHeader {
   my $header_flag = 0; # here is the flag/ It is "false" at first, and
                        # is set to "true" when any valid header element
                        # is encountered
-  local $_;
+
   $self->{'REPORT_DONE'} = 0;  # reset this bit for a new report
   while(defined($_ = $self->_readline() ) ) {
-      s/\(\s*\)//;      
-      if (/^Query=(?:\s+(.+))?/s) {
+      s/\(\s*\)//;
+      if ($_ =~ /^Query=(?:\s+([^\(]+))?/) {
 	  $header_flag = 1;	# valid header element found
 	  my $query = $1;
 	  while( defined($_ = $self->_readline() ) ) {
-	      # Continue reading query name until encountering either
-	      # a line that starts with "Database" or a blank line.
-	      # The latter condition is needed in order to be able to
-	      # parse megablast output correctly, since Database comes
-	      # before (not after) the query.
-	      if( ($_ =~ /^Database/) || ($_ =~ /^$/) ) {
-		  $self->_pushback($_); last;
-	      }	      
+	      if( $_ =~ /^Database/ ) { $self->_pushback($_); last; }
 	      $query .= $_;
 	  }
 	  $query =~ s/\s+/ /g;
-	  $query =~ s/\s+$//;
 	  $query =~ s/^>//;
 
 	  my $length = 0;
@@ -403,16 +388,10 @@ sub _parseHeader {
 	  $self->{'QUERY'} = $query;
 	  $self->{'LENGTH'} = $length;
       }
-      elsif (/^(<b>)?(T?BLAST[NPX])\s+([\w\.-]+)\s+(\[[\w-]*\])/o) { 
+      elsif ($_ =~ /^(<b>)?(T?BLAST[NPX])\s+([\w\.-]+)\s+(\[[\w-]*\])/) { 
 	  $self->{'BLAST_TYPE'} = $2; 
 	  $self->{'BLAST_VERSION'} = $3;
       }				# BLAST report type - not a valid header element # JB949
-      
-      # Support Paracel BTK output
-      elsif ( $_ =~ /(^[A-Z0-9_]+)\s+BTK\s+/ ) { 
-	  $self->{'BLAST_TYPE'} = $1;
-	  $self->{'BTK'} = 1;
-      } 
       elsif ($_ =~ /^Database:\s+(.+)/) {$header_flag = 1;$self->{'DATABASE'} = $1} # valid header element found
       elsif ($_ =~ /^\s*pattern\s+(\S+).*position\s+(\d+)\D/) {   
 	  # For PHIBLAST reports
@@ -421,18 +400,13 @@ sub _parseHeader {
 	  push (@{$self->{'QPATLOCATION'}}, $2);
       } 
       elsif (($_ =~ /^>/) && ($header_flag==1)) {$self->_pushback($_); return 1} # only leave if we have actually parsed a valid header!
-      elsif (($_ =~ /^Parameters|^\s+Database:/) && ($header_flag==1)) { 
-      # if we entered a header, and saw nothing before the stats at the end, 
-      # then it was empty
+      elsif (($_ =~ /^Parameters|^\s+Database:/) && ($header_flag==1)) { # if we entered a header, and saw nothing before the stats at the end, then it was empty
 	  $self->_pushback($_);
 	  return 0;		# there's nothing in the report
-      } elsif( /Reference:\s+Aaron E\. Darling/ ) {
-	  $self->{'BTK'} = 1;
-      }  
+      }
       # bug fix suggested by MI Sadowski via Martin Lomas
       # see bug report #1118
-      if( ref($self->_fh()) !~ /GLOB/ && 
-	  $self->_fh()->can('EOF') && eof($self->_fh()) ) {
+      if( ref($self->_fh()) !~ /GLOB/ && $self->_fh()->can('EOF') && eof($self->_fh()) ) {
 	  $self->warn("unexpected EOF in file\n");
 	  return -1;
       }
@@ -443,21 +417,15 @@ sub _parseHeader {
 sub _fastForward {
     my ($self) = @_;
     return 0 if $self->{'REPORT_DONE'}; # empty report
-    local $_;
     while(defined( $_ = $self->_readline() ) ) {
-	if (/^Histogram|^Searching|^Parameters|^\s+Database:|
-             ^\s+Posted date:/xo) {
+	if ($_ =~ /^Parameters|^\s+Database:|^\s+Posted date:/) {
 	    return 0;
-	} elsif( $self->{'BTK'} && /^BLAST/o ) {
-	    return 0;
-	} elsif( /^>/ ) {
+	} elsif( $_ =~ /^>/ ) {
 	    $self->_pushback($_);	
 	    return 1;
 	}
     }
-    unless( $self->{'BTK'} ) { # Paracel BTK reports have no footer
-	$self->warn("Possible error (1) while parsing BLAST report!");
-    }
+    $self->warn("Possible error (1) while parsing BLAST report!");
 }
 
 1;
