@@ -1,4 +1,4 @@
-# $Id: Sbjct.pm,v 1.33.4.1 2006/10/02 23:10:33 sendu Exp $
+# $Id: Sbjct.pm,v 1.23 2002/10/22 07:45:23 lapp Exp $
 ###############################################################################
 # Bio::Tools::BPlite::Sbjct
 ###############################################################################
@@ -26,16 +26,15 @@ Bio::Tools::BPlite::Sbjct - A Blast Subject (database search Hit)
 
 =head1 SYNOPSIS
 
-  use Bio::Tools::BPlite;
-  my $report = new Bio::Tools::BPlite(-fh=>\*STDIN);
-  while(my $sbjct = $report->nextSbjct) {
-      $sbjct->name;    # access to the hit name
-      "$sbjct";        # overloaded to return name
-      $sbjct->nextHSP; # gets the next HSP from the sbjct
-      while (my $hsp = $sbjct->nextHSP) {
- 	 # canonical form is again a while loop
-      }
-  }
+ use Bio::Tools::BPlite
+ my $report = new Bio::Tools::BPlite(-fh=>\*STDIN);
+ while(my $sbjct = $report->nextSbjct) {
+     $sbjct->name;    # access to the hit name
+     "$sbjct";        # overloaded to return name
+     $sbjct->nextHSP; # gets the next HSP from the sbjct
+     while(my $hsp = $sbjct->nextHSP) {
+	 # canonical form is again a while loop
+     }
 
 =head1 DESCRIPTION
 
@@ -62,16 +61,17 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+  bioperl-l@bioperl.org            - General discussion
+http://bioperl.org/MailList.shtml  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via the
-web:
+of the bugs and their resolution. Bug reports can be submitted via
+email or the web:
 
-  http://bugzilla.open-bio.org/
+  bioperl-bugs@bioperl.org
+  http://bugzilla.bioperl.org/
 
 =head1 AUTHOR - Peter Schattner
 
@@ -79,7 +79,7 @@ Email: schattner@alum.mit.edu
 
 =head1 CONTRIBUTORS
 
-Jason Stajich, jason-at-bioperl.org
+Jason Stajich, jason@cgt.mc.duke.edu
 
 =head1 APPENDIX
 
@@ -94,10 +94,12 @@ package Bio::Tools::BPlite::Sbjct;
 
 use strict;
 
+use Bio::Root::Root;        # root object to inherit from
 use Bio::Tools::BPlite::HSP; # we want to use HSP
 #use overload '""' => 'name';
+use vars qw(@ISA);
 
-use base qw(Bio::Root::Root);
+@ISA = qw(Bio::Root::Root);
 
 sub new {
     my ($class, @args) = @_;
@@ -177,7 +179,7 @@ sub nextFeaturePair {shift->nextHSP}; # just another name
 
 sub nextHSP {
   my ($self) = @_;  
-  return  if $self->{'HSP_ALL_PARSED'};
+  return undef if $self->{'HSP_ALL_PARSED'};
   
   ############################
   # get and parse scorelines #
@@ -185,20 +187,18 @@ sub nextHSP {
   my ($qframe, $sframe);
   my $scoreline = $self->_readline();
   my $nextline = $self->_readline();
-  return if not defined $nextline;
+  return undef if not defined $nextline;
   $scoreline .= $nextline;
   my ($score, $bits);
   if ($scoreline =~ /\d bits\)/) {
-      ($score, $bits) = ( $scoreline =~
-			  /Score = (\d+) \((\S+) bits\)/); # WU-BLAST
-  } else {
-      ($bits, $score) = ( $scoreline =~
-			  /Score =\s+(\S+) bits \((\d+)/); # NCBI-BLAST
+    ($score, $bits) = $scoreline =~
+      /Score = (\d+) \((\S+) bits\)/; # WU-BLAST
   }
-  unless( defined $bits && defined $score ) { 
-      $self->warn("Weird scoreline ($scoreline) bailing\n");
-      return;
+  else {
+    ($bits, $score) = $scoreline =~
+      /Score =\s+(\S+) bits \((\d+)/; # NCBI-BLAST
   }
+  
   my ($match, $hsplength) = ($scoreline =~ /Identities = (\d+)\/(\d+)/);
   my ($positive) = ($scoreline =~ /Positives = (\d+)/);
   my ($gaps) = ($scoreline =~ /Gaps = (\d+)/);
@@ -211,28 +211,24 @@ sub nextHSP {
   }
   $positive = $match if not defined $positive;
   $gaps = '0' if not defined $gaps;
-  my ($p)        = ($scoreline =~ /[Sum ]*P[\(\d+\)]* = (\S+)/);
-  unless (defined $p) {(undef, $p) = $scoreline =~ /Expect(\(\d+\))? =\s+(\S+)/}
-  my ($exp) = ($scoreline =~ /Expect(?:\(\d+\))? =\s+([^\s,]+)/);
-  $exp = -1 unless( defined $exp );
-
-  $self->throw("Unable to parse '$scoreline'") unless defined $score;
+  my ($p)        = $scoreline =~ /[Sum ]*P[\(\d+\)]* = (\S+)/;
+  if (not defined $p) {(undef, $p) = $scoreline =~ /Expect(\(\d+\))? =\s+(\S+)/}
+  $self->throw("Unable to parse '$scoreline'") if not defined $score;
   
   #######################
   # get alignment lines #
   #######################
   my (@hspline);
-  local $_;
   while( defined($_ = $self->_readline()) ) {
-      if (/^WARNING:|^NOTE:/) {
+      if ($_ =~ /^WARNING:|^NOTE:/) {
 	  while(defined($_ = $self->_readline())) {last if $_ !~ /\S/}
       }
-      elsif ( ! /\S/o)         {next}
-      elsif (/Strand HSP/o)    {next} # WU-BLAST non-data
-      elsif (/^\s*Strand/o)    {next} # NCBI-BLAST non-data
-      elsif (/^\s*Score/o)     {$self->_pushback($_); last}
+      elsif ($_ !~ /\S/)            {next}
+      elsif ($_ =~ /Strand HSP/)    {next} # WU-BLAST non-data
+      elsif ($_ =~ /^\s*Strand/)    {next} # NCBI-BLAST non-data
+      elsif ($_ =~ /^\s*Score/)     {$self->_pushback($_); last}
 
-      elsif (/^>|^Histogram|^Searching|^Parameters|^\s+Database:|^CPU\stime|^\s*Lambda|^\s+Subset/o)   
+      elsif ($_ =~ /^>|^Parameters|^\s+Database:|^CPU\stime|^\s*Lambda/)   
       {    
 	  #ps 5/28/01	
 	  # elsif ($_ =~ /^>|^Parameters|^\s+Database:|^CPU\stime/)   {
@@ -240,11 +236,8 @@ sub nextHSP {
 
 	  $self->{'HSP_ALL_PARSED'} = 1;
 	  last;
-      } elsif( /^BLAST/ ) {
-	  $self->_pushback($_);
-	  $self->{'HSP_ALL_PARSED'} = 1;
-	  last;
-      } elsif( $_ =~ /^\s*Frame/ ) {
+      }
+      elsif( $_ =~ /^\s*Frame/ ) {
 	  if ($self->report_type() eq 'TBLASTX') {
 	      ($qframe, $sframe) = $_ =~ /Frame = ([\+-]\d)\s+\/\s+([\+-]\d)/;
 	  } elsif ($self->report_type() eq 'TBLASTN') {
@@ -272,13 +265,13 @@ sub nextHSP {
   
   for(my $i=0;$i<@hspline;$i+=3) {
     # warn $hspline[$i], $hspline[$i+2];
-    $hspline[$i]   =~ /^(?:Query|Trans):\s+(\d+)\s*([\D\S]+)\s+(\d+)/o;
+    $hspline[$i]   =~ /^Query:\s+(\d+)\s*([\D\S]+)\s+(\d+)/;
     $ql = $2; $qb = $1 unless $qb; $qe = $3;
     
     my $offset = index($hspline[$i], $ql);
     $as = substr($hspline[$i+1], $offset, CORE::length($ql));
     
-    $hspline[$i+2] =~ /^Sbjct:\s+(\d+)\s*([\D\S]+)\s+(\d+)/o;
+    $hspline[$i+2] =~ /^Sbjct:\s+(\d+)\s*([\D\S]+)\s+(\d+)/;
     $sl = $2; $sb = $1 unless $sb; $se = $3;
 
     push @QL, $ql; push @SL, $sl; push @AS, $as;
@@ -294,7 +287,7 @@ sub nextHSP {
 # {'PARENT'}->qlength will not be available.
   my ($qname, $qlength) = ('unknown','unknown');
   if ($self->{'PARENT'}->can('query')) {
-	$qname   = $self->{'PARENT'}->query;
+	$qname = $self->{'PARENT'}->query;
 	$qlength = $self->{'PARENT'}->qlength;
   }	
   
@@ -306,7 +299,6 @@ sub nextHSP {
        '-gaps'       => $gaps,
        '-hsplength'  => $hsplength,
        '-p'          => $p,
-       '-exp'        => $exp,
        '-queryBegin' => $qb, 
        '-queryEnd'   => $qe, 
        '-sbjctBegin' => $sb,
@@ -315,10 +307,10 @@ sub nextHSP {
        '-sbjctSeq'   => $sl,
        '-homologySeq'=> $as, 
        '-queryName'  => $qname,
-#			'-queryName'=>$self->{'PARENT'}->query,
+#					'-queryName'=>$self->{'PARENT'}->query,
        '-sbjctName'  => $self->{'NAME'},
        '-queryLength'=> $qlength,
-#		       	'-queryLength'=>$self->{'PARENT'}->qlength,
+#					'-queryLength'=>$self->{'PARENT'}->qlength,
        '-sbjctLength'=> $self->{'LENGTH'},
        '-queryFrame' => $qframe,
        '-sbjctFrame' => $sframe,
