@@ -1,8 +1,8 @@
-# $Id: Genomewise.pm,v 1.6.4.1 2006/10/02 23:10:32 sendu Exp $
+# $Id: Genomewise.pm,v 1.1 2002/11/24 14:57:15 jason Exp $
 #
 # BioPerl module for Bio::Tools::Genomewise
 #
-# Copyright Jason Stajich <jason-at-bioperl.org>
+# Copyright Jason Stajich <jason@bioperl.org>
 #
 # You may distribute this module under the same terms as perl itself
 #
@@ -31,9 +31,8 @@ Bio::Tools::Genomewise - Results of one Genomewise run
 
 This is the parser for the output of Genewise. It takes either a file
 handle or a file name and returns a
-Bio::SeqFeature::Gene::GeneStructure object.  You will need to specify
-the proper target sequence id on the object with the
-$feature-E<gt>seq_id($seqid).
+Bio::SeqFeature::Gene::GeneStructure object.  You will need to specify the 
+proper target sequence id on the object with the $feature->seq_id($seqid).
 
 =head1 FEEDBACK
 
@@ -43,21 +42,21 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to one
 of the Bioperl mailing lists.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+  bioperl-l@bioperl.org          - General discussion
+  http://bio.perl.org/MailList.html             - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via the
-web:
+the bugs and their resolution.  Bug reports can be submitted via email
+or the web:
 
-  http://bugzilla.open-bio.org/
+  bioperl-bugs@bio.perl.org
+  http://bugzilla.bioperl.org/
 
-=head1 AUTHOR - Fugu Team, Jason Stajich 
+=head1 AUTHOR - Fugu Team 
 
- Email: fugui-at-worf.fugu-sg.org
-        jason-at-bioperl-dot-org
+ Email: fugui@worf.fugu-sg.org
 
 =head1 APPENDIX
 
@@ -70,9 +69,10 @@ The rest of the documentation details each of the object methods. Internal metho
 
 
 package Bio::Tools::Genomewise;
-use vars qw($Srctag);
+use vars qw(@ISA $Srctag);
 use strict;
 
+use Bio::Tools::Genewise;
 use Bio::Tools::AnalysisResult;
 use Bio::SeqFeature::Generic;
 use Bio::SeqFeature::Gene::Exon;
@@ -80,7 +80,7 @@ use Bio::SeqFeature::FeaturePair;
 use Bio::SeqFeature::Gene::Transcript;
 use Bio::SeqFeature::Gene::GeneStructure;
 
-use base qw(Bio::Tools::Genewise);
+@ISA = qw(Bio::Tools::Genewise);
 
 $Srctag = 'genomewise';
 
@@ -164,7 +164,7 @@ sub next_prediction {
     my $genes;
     while ($_ = $self->_readline) {
 	$self->debug( $_ ) if( $self->verbose > 0);
-	last if m{^//};
+	last if( /^\/\//);
 
 	if( /^Gene\s+\d+\s*$/ ) {
 	    $genes = new Bio::SeqFeature::Gene::GeneStructure
@@ -215,5 +215,4 @@ sub next_prediction {
     }
     return $genes;
 }
-
 1;
