@@ -1,4 +1,4 @@
-# $Id: RemoteBlast.pm,v 1.14.2.2 2003/09/03 18:29:50 jason Exp $
+# $Id: RemoteBlast.pm,v 1.14 2002/12/23 13:01:50 birney Exp $
 #
 # BioPerl module for Bio::Tools::Run::RemoteBlast
 #
@@ -40,7 +40,7 @@ via HTTP
 
   my $v = 1;
   #$v is just to turn on and off the messages
-
+  
   my $str = Bio::SeqIO->new(-file=>'amino.fa' , '-format' => 'fasta' );
 
   while (my $input = $str->next_seq()){
@@ -165,7 +165,7 @@ BEGIN {
 			'FORMAT_TYPE'    => 'Text',
 			);
 
-    $RIDLINE = 'RID\s+=\s+(\S+)';
+    $RIDLINE = 'RID\s+=\s+(\d+-\d+-\d+)';
 
     %BLAST_PARAMS = ( 'prog' => 'blastp',
 		       'data' => 'nr',
