@@ -1,4 +1,4 @@
-# $Id$
+# $Id: NodeI.pm,v 1.19 2002/12/24 17:52:03 jason Exp $
 #
 # BioPerl module for Bio::Tree::NodeI
 #
@@ -246,7 +246,7 @@ sub height{
    
    if( $self->is_Leaf ) { 
        if( !defined $self->branch_length ) { 
-	   $self->debug(sprintf("Trying to calculate height of a node when a Node (%s) has an undefined branch_length\n",$self->id || '?' ));
+	   $self->debug(sprintf("Trying to calculate height of a node when a Node (%s) has an undefined branch_length",$self->id || '?' ));
 	   return 0;
        }
        return $self->branch_length;
